@@ -1,7 +1,6 @@
+# -*- coding: utf-8 -*-
 #
-# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
-#
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -14,7 +13,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-""" Base tests cases and test utilities """
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
+"""Base test cases and test utilities."""
+
 from __future__ import with_statement
 
 import contextlib
@@ -24,9 +37,12 @@ import os
 import shutil
 import sys
 
-from twisted.internet import defer
+from collections import defaultdict
+from functools import wraps
+
+from twisted.internet import defer, reactor
 from twisted.trial.unittest import TestCase as TwistedTestCase
-from ubuntuone.devtools.testcase import skipIfOS
+from ubuntuone.devtools.testcases import skipIfOS
 from zope.interface import implements
 from zope.interface.verify import verifyObject
 
@@ -35,6 +51,7 @@ from ubuntuone.syncdaemon import (
     action_queue,
     event_queue,
     filesystem_manager as fs_manager,
+    interaction_interfaces,
     interfaces,
     volume_manager,
     main,
@@ -42,6 +59,7 @@ from ubuntuone.syncdaemon import (
     tritcask,
 )
 from ubuntuone.syncdaemon import logger
+from ubuntuone import platform
 from ubuntuone.platform import (
     can_write,
     make_dir,
@@ -261,6 +279,17 @@ class FakeMain(main.Main):
         return defer.succeed(True)
 
 
+class FakeTunnelRunner(object):
+    """A fake proxy.tunnel_client.TunnelRunner."""
+
+    def __init__(self, *args):
+        """Fake a proxy tunnel."""
+
+    def get_client(self):
+        """Always return the reactor."""
+        return defer.succeed(reactor)
+
+
 class BaseTwistedTestCase(TwistedTestCase):
     """Base TestCase with helper methods to handle temp dir.
 
@@ -269,6 +298,8 @@ class BaseTwistedTestCase(TwistedTestCase):
         mmtree(path): support read-only shares
         makedirs(path): support read-only shares
     """
+    MAX_FILENAME = 32 # some platforms limit lengths of filenames
+    tunnel_runner_class = FakeTunnelRunner
 
     def mktemp(self, name='temp'):
         """ Customized mktemp that accepts an optional name argument. """
@@ -286,8 +317,8 @@ class BaseTwistedTestCase(TwistedTestCase):
         # check if we already generated the root path
         if self.__root:
             return self.__root
-        base = os.path.join(self.__class__.__module__,
-                            self.__class__.__name__,
+        base = os.path.join(self.__class__.__module__[:self.MAX_FILENAME],
+                            self.__class__.__name__[:self.MAX_FILENAME],
                             self._testMethodName)
         # use _trial_temp dir, it should be TRIAL_TEMP_DIR or os.getcwd()
         # define the root temp dir of the testcase, pylint: disable=W0201
@@ -310,23 +341,23 @@ class BaseTwistedTestCase(TwistedTestCase):
             set_dir_readwrite(path)
 
         if sys.platform == 'win32':
-            # path is a byte sequence encoded with utf8. If we pass this to
+            # path is a byte sequence encoded with utf-8. If we pass this to
             # os.walk, in windows, we'll get results encoded with mbcs
-            path = path.decode('utf8')
+            path = path.decode('utf-8')
 
         for dirpath, dirs, files in os.walk(path):
             for adir in dirs:
                 adir = os.path.join(dirpath, adir)
                 if sys.platform == 'win32':
                     assert isinstance(adir, unicode)
-                    adir = adir.encode('utf8')
+                    adir = adir.encode('utf-8')
                 if not can_write(adir):
                     set_dir_readwrite(adir)
 
         if sys.platform == 'win32':
             # in windows, we need to pass a unicode, literal path to
             # shutil.rmtree, otherwise we can't remove "deep and wide" paths
-            path = u'\\\\?\\' + path.decode('utf8')
+            path = u'\\\\?\\' + path.decode('utf-8')
 
         # Instead of ignoring the errors when removing trees, we are temporarly
         # printing a message to stdout to caught everyone's attention.
@@ -370,16 +401,23 @@ class BaseTwistedTestCase(TwistedTestCase):
         self.log = logging.getLogger("ubuntuone.SyncDaemon.TEST")
         self.log.info("starting test %s.%s", self.__class__.__name__,
                       self._testMethodName)
+        # Patch the user home
+        self.home_dir = self.mktemp('ubuntuonehacker')
+        self.patch(platform, "xdg_home", self.home_dir)
+        self.patch(action_queue.tunnel_runner, "TunnelRunner",
+                   self.tunnel_runner_class)
 
 
 class FakeMainTestCase(BaseTwistedTestCase):
     """A testcase that starts up a Main instance."""
 
+    timeout = 2
+
     @defer.inlineCallbacks
     def setUp(self):
         """Setup the infrastructure for the test."""
         yield super(FakeMainTestCase, self).setUp()
-        self.timeout = 2
+
         self.data_dir = self.mktemp('data_dir')
         self.partials_dir = self.mktemp('partials')
         self.root_dir = self.mktemp('root_dir')
@@ -393,6 +431,12 @@ class FakeMainTestCase(BaseTwistedTestCase):
         self.action_q = self.main.action_q
         self.event_q.push('SYS_INIT_DONE')
 
+        self._called = None
+
+    def _set_called(self, *args, **kwargs):
+        """Keep track of patched calls."""
+        self._called = (args, kwargs)
+
 
 class FakeVolumeManager(object):
     """ A volume manager that only knows one share, the root"""
@@ -472,6 +516,141 @@ class FakeLogger(object):
         self._log(self.logged['info'], txt, args)
 
 
+class FakeCommand(object):
+    """A fake command."""
+
+    is_runnable = True
+    running = True
+
+    def __init__(self, share_id=None, node_id=None,
+                 other='', path=None, **kwargs):
+        self.share_id = share_id
+        self.node_id = node_id
+        self.other = other
+        self.path = path
+        self.cancelled = False
+        self.log = logging.getLogger('ubuntuone.SyncDaemon')
+
+    @property
+    def paused(self):
+        """Is this command paused?"""
+        return not self.running
+
+    @property
+    def uniqueness(self):
+        """Fake uniqueness."""
+        if self.share_id is None and self.node_id is None:
+            return self
+        else:
+            return (self.__class__.__name__, self.share_id, self.node_id)
+
+    def run(self):
+        """Just succeed."""
+        return defer.succeed(None)
+
+    def to_dict(self):
+        """Just send both values."""
+        d = dict(share_id=self.share_id, node_id=self.node_id,
+                 other=self.other, running=self.running)
+        # some commands have path, others don't
+        if self.path is not None:
+            d['path'] = self.path
+        return d
+
+    def pause(self):
+        """Pause running."""
+        self.running = False
+
+    def cancel(self):
+        """Cancel!"""
+        self.cancelled = True
+
+
+class FakeUpload(FakeCommand, action_queue.Upload):
+    """Fake command that inherits from Upload."""
+
+    def __init__(self, *args):
+        super(FakeUpload, self).__init__(*args)
+        self.path = 'upload_path'
+        self.tempfile = None
+
+
+class FakeDownload(FakeCommand, action_queue.Download):
+    """Fake command that inherits from Download."""
+
+    def __init__(self, *args):
+        super(FakeDownload, self).__init__(*args)
+        self.path = 'download_path'
+
+
+class EmptyCommand(FakeCommand):
+    """A command without any attributes."""
+
+    def __init__(self):
+        """__init__ that doesn't set any attributes."""
+
+    def to_dict(innerself):
+        """We have no attributes, return an empty dict."""
+        return {}
+
+
+class FakedObject(object):
+    """A class that records every call clients made to it."""
+
+    def __init__(self, *args, **kwargs):
+        self._called = defaultdict(list)
+
+    def __getattribute__(self, attr_name):
+        """Override so we can record calls to members."""
+        try:
+            result = super(FakedObject, self).__getattribute__(attr_name)
+        except AttributeError:
+            result = lambda *a, **kw: None
+            super(FakedObject, self).__setattr__(attr_name, result)
+
+        if attr_name == '_called':
+            return result
+
+        called = super(FakedObject, self).__getattribute__('_called')
+
+        def wrap_me(f):
+            """Wrap 'f'."""
+            @wraps(f)
+            def inner(*a, **kw):
+                """Keep track of calls to 'f', execute it and return result."""
+                called[attr_name].append((a, kw))
+                return f(*a, **kw)
+
+            return inner
+
+        return wrap_me(result)
+
+
+class FakedService(interaction_interfaces.SyncdaemonService):
+    """A faked SyncdaemonService."""
+
+    clients = (
+        'config',
+        'events',
+        'event_listener',
+        'file_system',
+        'folders',
+        'public_files',
+        'shares',
+        'status',
+        'sync',
+    )
+
+    def __init__(self, main, send_events=False, interface=None):
+        super(FakedService, self).__init__(main, send_events, interface)
+        self.oauth_credentials = ('foo', 'bar')
+
+    def _create_children(self):
+        """Override parent's method to have fakes for children."""
+        for client in self.clients:
+            setattr(self, client, FakedObject())
+
+
 class Listener(object):
     """Helper class to gather events."""
 
