@@ -3,7 +3,7 @@
  *
  * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
  *
- * Copyright 2010 Canonical Ltd.
+ * Copyright 2010-2012 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -17,6 +17,19 @@
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
+ *
  */
 
 #include "config.h"
@@ -59,6 +72,8 @@ file_published_cb (DBusGProxy *proxy, GHashTable *hash, gpointer user_data)
 	SyncdaemonDaemon *daemon = NULL;
 	SyncdaemonPublicfilesInterface *interface = SYNCDAEMON_PUBLICFILES_INTERFACE (user_data);
 
+    g_return_if_fail (hash != NULL);
+
 	g_object_get (G_OBJECT (interface), "daemon", &daemon, NULL);
 	if (daemon != NULL) {
 		SyncdaemonFileInfo *finfo;
@@ -79,6 +94,8 @@ got_public_files_cb (DBusGProxy *proxy, GPtrArray *files, gpointer user_data)
 	SyncdaemonDaemon *daemon = NULL;
 	SyncdaemonPublicfilesInterface *interface = SYNCDAEMON_PUBLICFILES_INTERFACE (user_data);
 
+    g_return_if_fail (files != NULL);
+
 	if (interface->priv->public_files == NULL) {
 		interface->priv->public_files = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
 	}
@@ -106,6 +123,8 @@ public_access_change_error_cb (DBusGProxy *proxy, GHashTable *hash, gchar *error
 	SyncdaemonDaemon *daemon = NULL;
 	SyncdaemonPublicfilesInterface *interface = SYNCDAEMON_PUBLICFILES_INTERFACE (user_data);
 
+    g_return_if_fail (hash != NULL);
+
 	g_object_get (G_OBJECT (interface), "daemon", &daemon, NULL);
 	if (daemon != NULL) {
 		SyncdaemonFileInfo *finfo;
