@@ -1,10 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# tests.eventlog.test_zg_listener - test logging ZG events
-#
-# Author: Alejandro J. Cura <alecu@canonical.com>
-#
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -17,6 +13,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Test the event logging from SyncDaemon into Zeitgeist."""
 
 import logging
@@ -32,7 +41,7 @@ from zeitgeist.datamodel import Interpretation, Manifestation
 # disabled, but fake it for running tests on lucid
 try:
     import zeitgeist.mimetypes
-    assert(zeitgeist.mimetypes is not None) # make pyflakes happy
+    assert(zeitgeist.mimetypes is not None)  # make pyflakes happy
 except ImportError:
 
     class FakeMimetypes(object):
@@ -47,6 +56,7 @@ except ImportError:
 from contrib.testing.testcase import (
         FakeMain, FakeMainTestCase, BaseTwistedTestCase)
 from ubuntuone.devtools.handlers import MementoHandler
+from ubuntuone.platform import expand_user
 from ubuntuone.storageprotocol import client, delta
 from ubuntuone.storageprotocol.request import ROOT
 from ubuntuone.storageprotocol.sharersp import NotifyShareHolder
@@ -68,6 +78,7 @@ from ubuntuone.eventlog.zg_listener import (
         STORAGE_DELETED, STORAGE_NETWORK, STORAGE_LOCAL)
 from ubuntuone.syncdaemon.sync import Sync
 from ubuntuone.syncdaemon.volume_manager import (
+    ACCESS_LEVEL_RO,
     get_udf_path, Share, Shared, UDF,
 )
 from tests.syncdaemon.test_action_queue import (
@@ -100,6 +111,7 @@ class MockLogger(object):
         if d:
             d.callback(event)
 
+
 def listen_for(event_q, event, callback, count=1, collect=False):
     """Setup a EQ listener for the specified event."""
     class Listener(object):
@@ -123,7 +135,7 @@ def listen_for(event_q, event, callback, count=1, collect=False):
                     callback(args)
 
     listener = Listener()
-    setattr(listener, 'handle_'+event, listener._handle_event)
+    setattr(listener, 'handle_' + event, listener._handle_event)
     event_q.subscribe(listener)
     return listener
 
@@ -167,7 +179,8 @@ class ZeitgeistSharesTestCase(ZeitgeistListenerTestCase):
         d = defer.Deferred()
         self._listen_for('AQ_CREATE_SHARE_OK', d.callback, 1, collect=True)
         self.patch(self.main.action_q, "create_share", fake_create_share)
-        self.vm.create_share(path, fake_username, 'shared_name', 'View')
+        self.vm.create_share(path, fake_username, 'shared_name',
+                             ACCESS_LEVEL_RO)
 
         yield d
 
@@ -188,7 +201,8 @@ class ZeitgeistSharesTestCase(ZeitgeistListenerTestCase):
                                    marker=marker)
 
         self.patch(self.main.action_q, "create_share", fake_create_share)
-        self.vm.create_share(path, fake_username, 'shared_name', 'View')
+        self.vm.create_share(path, fake_username, 'shared_name',
+                             ACCESS_LEVEL_RO)
 
         self.assert_folder_shared_is_logged(path, fake_username)
 
@@ -222,7 +236,6 @@ class ZeitgeistSharesTestCase(ZeitgeistListenerTestCase):
                           MANIFESTATION_U1_CONTACT_DATA_OBJECT)
         self.assertEqual(other_user.text, fake_username)
 
-
     @defer.inlineCallbacks
     def test_share_deleted_is_logged(self):
         """Test VolumeManager.delete_share."""
@@ -314,7 +327,6 @@ class ZeitgeistSharesTestCase(ZeitgeistListenerTestCase):
                           MANIFESTATION_U1_CONTACT_DATA_OBJECT)
         self.assertEqual(other_user.text, fake_username)
 
-
     @defer.inlineCallbacks
     def test_share_unaccepted_is_logged(self):
         """Test that an unaccepted share event is logged."""
@@ -365,20 +377,6 @@ class ZeitgeistSharesTestCase(ZeitgeistListenerTestCase):
 class ZeitgeistUDFsTestCase(ZeitgeistListenerTestCase):
     """Tests for all UDFs-related zeitgeist events."""
 
-    @defer.inlineCallbacks
-    def setUp(self):
-        """Initialize this test instance."""
-        yield super(ZeitgeistUDFsTestCase, self).setUp()
-        self.home_dir = self.mktemp('ubuntuonehacker')
-        self._old_home = os.environ['HOME']
-        os.environ['HOME'] = self.home_dir
-
-    @defer.inlineCallbacks
-    def tearDown(self):
-        """Finalize this test instance."""
-        os.environ['HOME'] = self._old_home
-        yield super(ZeitgeistUDFsTestCase, self).tearDown()
-
     def _create_udf(self, id, node_id, suggested_path, subscribed=True):
         """Create an UDF and returns it and the volume."""
         path = get_udf_path(suggested_path)
@@ -399,7 +397,7 @@ class ZeitgeistUDFsTestCase(ZeitgeistListenerTestCase):
         def create_udf(path, name, marker):
             """Fake create_udf."""
             # check that the marker is the full path to the udf
-            expanded_path = os.path.expanduser(path.encode('utf-8'))
+            expanded_path = expand_user(path.encode('utf-8'))
             udf_path = os.path.join(expanded_path, name.encode('utf-8'))
             if str(marker) != udf_path:
                 d.errback(ValueError("marker != path - "
@@ -448,7 +446,7 @@ class ZeitgeistUDFsTestCase(ZeitgeistListenerTestCase):
         def create_udf(path, name, marker):
             """Fake create_udf."""
             # check that the marker is the full path to the udf
-            expanded_path = os.path.expanduser(path.encode('utf-8'))
+            expanded_path = expand_user(path.encode('utf-8'))
             udf_path = os.path.join(expanded_path, name.encode('utf-8'))
             if str(marker) != udf_path:
                 d.errback(ValueError("marker != path - "
@@ -523,7 +521,7 @@ class ZeitgeistUDFsTestCase(ZeitgeistListenerTestCase):
         self.assertEqual(folder.manifestation,
                           Manifestation.FILE_DATA_OBJECT)
         self.assertTrue(folder.origin.startswith(URI_PROTOCOL_U1))
-        self.assertEqual(folder.text, folder_name)
+        self.assertEqual(folder.text.decode('utf-8'), folder_name)
         self.assertEqual(folder.mimetype, DIRECTORY_MIMETYPE)
         self.assertEqual(folder.storage, STORAGE_LOCAL)
 
@@ -576,8 +574,7 @@ class ZeitgeistRemoteFileSyncTestCase(ConnectedBaseTestCase):
         self.share_id = ""
         self.command = MyUpload(request_queue, share_id=self.share_id,
                                 node_id='a_node_id', previous_hash='prev_hash',
-                                hash='yadda', crc32=0, size=0, path='path',
-                                fileobj_factory=lambda: None)
+                                hash='yadda', crc32=0, size=0, path='path')
         self.command.make_logger()
         self.command.tempfile = FakeTempFile(self.mktemp('tmpdir'))
         self.fsm = self.action_queue.main.fs
@@ -858,7 +855,7 @@ class ZeitgeistLocalFileSyncTestCase(BaseTwistedTestCase):
         listen_for(self.main.event_q, 'SV_FILE_NEW', d.callback)
         listen_for(self.main.event_q, 'AQ_DOWNLOAD_FINISHED', d2.callback)
 
-        deltas = [ self.filemp3delta ]
+        deltas = [self.filemp3delta]
         kwargs = dict(volume_id=ROOT, delta_content=deltas, end_generation=11,
                       full=True, free_bytes=10)
         self.main.sync.handle_AQ_DELTA_OK(**kwargs)
@@ -869,7 +866,7 @@ class ZeitgeistLocalFileSyncTestCase(BaseTwistedTestCase):
         self.assertEqual(node.is_dir, False)
         self.assertEqual(node.generation, self.filemp3delta.generation)
 
-        yield d # wait for SV_FILE_NEW
+        yield d  # wait for SV_FILE_NEW
 
         dlargs = dict(
             share_id=self.filemp3delta.share_id,
@@ -877,7 +874,7 @@ class ZeitgeistLocalFileSyncTestCase(BaseTwistedTestCase):
             server_hash="server hash")
         self.main.event_q.push("AQ_DOWNLOAD_FINISHED", **dlargs)
 
-        yield d2 # wait for AQ_DOWNLOAD_FINISHED
+        yield d2  # wait for AQ_DOWNLOAD_FINISHED
 
         self.assertEqual(len(self.listener.zg.events), 1)
         event = self.listener.zg.events[0]
@@ -905,7 +902,7 @@ class ZeitgeistLocalFileSyncTestCase(BaseTwistedTestCase):
         d = defer.Deferred()
         listen_for(self.main.event_q, 'SV_DIR_NEW', d.callback)
 
-        deltas = [ self.dirdelta ]
+        deltas = [self.dirdelta]
         kwargs = dict(volume_id=ROOT, delta_content=deltas, end_generation=11,
                       full=True, free_bytes=10)
         self.main.sync.handle_AQ_DELTA_OK(**kwargs)
@@ -916,7 +913,7 @@ class ZeitgeistLocalFileSyncTestCase(BaseTwistedTestCase):
         self.assertEqual(node.is_dir, True)
         self.assertEqual(node.generation, self.dirdelta.generation)
 
-        yield d # wait for SV_DIR_NEW
+        yield d  # wait for SV_DIR_NEW
 
         self.assertEqual(len(self.listener.zg.events), 1)
         event = self.listener.zg.events[0]
@@ -946,7 +943,7 @@ class ZeitgeistLocalFileSyncTestCase(BaseTwistedTestCase):
         listen_for(self.main.event_q, 'SV_FILE_NEW', d.callback)
         listen_for(self.main.event_q, 'AQ_DOWNLOAD_FINISHED', d2.callback)
 
-        deltas = [ self.filemp3delta ]
+        deltas = [self.filemp3delta]
         kwargs = dict(volume_id=ROOT, delta_content=deltas, end_generation=11,
                       full=True, free_bytes=10)
         self.main.sync.handle_AQ_DELTA_OK(**kwargs)
@@ -957,7 +954,7 @@ class ZeitgeistLocalFileSyncTestCase(BaseTwistedTestCase):
         self.assertEqual(node.is_dir, False)
         self.assertEqual(node.generation, self.filemp3delta.generation)
 
-        yield d # wait for SV_FILE_NEW
+        yield d  # wait for SV_FILE_NEW
 
         # remove from the recent list
         local_file_id = (self.filemp3delta.share_id, self.filemp3delta.node_id)
@@ -969,7 +966,7 @@ class ZeitgeistLocalFileSyncTestCase(BaseTwistedTestCase):
             server_hash="server hash")
         self.main.event_q.push("AQ_DOWNLOAD_FINISHED", **dlargs)
 
-        yield d2 # wait for AQ_DOWNLOAD_FINISHED
+        yield d2  # wait for AQ_DOWNLOAD_FINISHED
 
         self.assertEqual(len(self.listener.zg.events), 1)
         event = self.listener.zg.events[0]
