@@ -402,6 +402,32 @@ class ArgsTestCase(CredentialsManagementTestCase):
         self.assertEqual(self.sso_server._args, params)
 
 
+class DictSignatureTestCase(DBusTestCase):
+    """Test the errors with dict signatures."""
+
+    def verify(self, app_name, options_dict, reply_handler, error_handler):
+        """Verify that the options_dict is a dbus.Dictionary."""
+        self.assertIsInstance(options_dict, dbus.Dictionary)
+
+    def test_find_credentials_dict_signature(self):
+        """Test for find_credentials."""
+        creds_man = CredentialsManagement()
+        self.patch(creds_man.sso_proxy, "find_credentials", self.verify)
+        creds_man.find_credentials()
+
+    def test_find_credentials_sync_dict_signature(self):
+        """Test for find_credentials_sync."""
+        creds_man = CredentialsManagement()
+        self.patch(creds_man.sso_proxy, "find_credentials_sync", self.verify)
+        creds_man.find_credentials_sync()
+
+    def test_clear_credentials_dict_signature(self):
+        """Test for clear_credentials."""
+        creds_man = CredentialsManagement()
+        self.patch(creds_man.sso_proxy, "clear_credentials", self.verify)
+        creds_man.clear_credentials()
+
+
 class SameAppNoErrorTestCase(CredentialsManagementTestCase):
     """Test case when the app_name matches APP_NAME and there was no error."""
 
