@@ -34,6 +34,7 @@ import logging
 import os
 
 from twisted.internet import defer, reactor
+from twisted.trial.unittest import TestCase as PlainTestCase
 
 from ubuntuone.syncdaemon import (
     event_queue,
@@ -434,3 +435,43 @@ class WatchTests(BaseFSMonitorTestCase):
         self.monitor.rm_watch(path_ancestor)
         self.assertEqual(self.monitor._general_watchs, {})
         self.assertEqual(self.monitor._ancestors_watchs, {})
+
+
+class FakeEvent(object):
+    """A fake event."""
+
+    mask = 0
+    name = ""
+
+
+class ECryptFsTestCase(PlainTestCase):
+    """Tests for the eCryptFS weirdness."""
+
+    def test_close_write_on_folders_is_ignored(self):
+        """When eCryptFS sends CLOSE_WRITE on folders, ignore it"""
+        result = []
+        monitor = None
+        processor = filesystem_notifications._GeneralINotifyProcessor(monitor)
+        self.patch(processor.general_processor, "push_event", result.append)
+
+        fake_event = FakeEvent()
+        fake_event.mask = filesystem_notifications.pyinotify.IN_ISDIR
+        fake_event.name = "/fake/directory/path"
+        processor.process_IN_CLOSE_WRITE(fake_event)
+
+        self.assertNotIn(fake_event, result)
+
+
+    def test_close_write_on_files_is_handled(self):
+        """When anything sends CLOSE_WRITE on files, handle it."""
+        result = []
+        monitor = None
+        processor = filesystem_notifications._GeneralINotifyProcessor(monitor)
+        self.patch(processor.general_processor, "push_event", result.append)
+
+        fake_event = FakeEvent()
+        fake_event.mask = filesystem_notifications.pyinotify.IN_CLOSE_WRITE
+        fake_event.name = "/fake/directory/path"
+        processor.process_IN_CLOSE_WRITE(fake_event)
+
+        self.assertIn(fake_event, result)
