@@ -2,7 +2,7 @@
 #
 # Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,13 +15,31 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Linux specific tests for the platform module."""
 
 import logging
 import os
+import sys
 
-import gio
+if 'gobject' in sys.modules and sys.modules['gobject'] is not None:
+    import gio
+    GIO_NOT_SUPPORTED = gio.ERROR_NOT_SUPPORTED
+else:
+    from gi.repository import Gio as gio
+    GIO_NOT_SUPPORTED = gio.IOErrorEnum.NOT_SUPPORTED
 
 from twisted.internet import defer
 from ubuntuone.devtools.handlers import MementoHandler
@@ -42,7 +60,12 @@ class FakeGIOFile(object):
     def __init__(self, path):
         pass
 
-    def trash(self):
+    @classmethod
+    def new_for_path(klass, path):
+        """Fake new_for_path for GI."""
+        return klass(path)
+
+    def trash(self, *args):
         """Fake trash call."""
         return self._bad_trash_call
 
@@ -98,7 +121,7 @@ class OSWrapperTests(test_os_helper.OSWrapperTests):
 
     def test_movetotrash_file_systemnotcapable(self):
         """The system is not capable of moving into trash."""
-        FakeGIOFile._bad_trash_call = gio.ERROR_NOT_SUPPORTED
+        FakeGIOFile._bad_trash_call = GIO_NOT_SUPPORTED
         self.patch(gio, "File", FakeGIOFile)
         path = os.path.join(self.basedir, 'foo')
         open_file(path, 'w').close()
@@ -110,7 +133,7 @@ class OSWrapperTests(test_os_helper.OSWrapperTests):
 
     def test_movetotrash_dir_systemnotcapable(self):
         """The system is not capable of moving into trash."""
-        FakeGIOFile._bad_trash_call = gio.ERROR_NOT_SUPPORTED
+        FakeGIOFile._bad_trash_call = GIO_NOT_SUPPORTED
         self.patch(gio, "File", FakeGIOFile)
         path = os.path.join(self.basedir, 'foo')
         os.mkdir(path)
