@@ -2,7 +2,7 @@
 #
 # Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,6 +15,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for the session inhibition DBus client."""
 
 import dbus
@@ -22,8 +35,8 @@ import operator
 
 from dbus.mainloop.glib import DBusGMainLoop
 from twisted.internet.defer import inlineCallbacks
+from ubuntuone.devtools.testcases.dbus import DBusTestCase
 
-from ubuntuone.devtools.testcase import DBusTestCase
 from ubuntuone.platform.linux import session
 
 INHIBIT_ALL = (session.INHIBIT_LOGGING_OUT |
