@@ -3,7 +3,7 @@
 # Authors: Manuel de la Pena <manuel@canonical.com>
 #          Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -16,6 +16,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Platform independent tests for the credentials management."""
 
 import platform
@@ -28,16 +41,26 @@ from functools import wraps
 from twisted.internet import defer
 from twisted.trial.unittest import TestCase
 
+from contrib.testing.testcase import FAKED_CREDENTIALS
 from ubuntuone import clientdefs
 from ubuntuone.platform.credentials import (
     BASE_PING_URL,
     CredentialsError,
     CredentialsManagementTool,
+    DESCRIPTION,
+    HELP_TEXT_KEY,
     NO_OP,
     PING_URL,
+    PING_URL_KEY,
     platform_data,
+    POLICY_URL,
+    POLICY_URL_KEY,
+    TC_URL,
+    TC_URL_KEY,
+    UI_EXECUTABLE_KEY,
+    UI_EXECUTABLE_QT,
+    UI_PARAMS,
 )
-from contrib.testing.testcase import FAKED_CREDENTIALS
 
 
 class FakedSignal(object):
@@ -227,6 +250,17 @@ class CredentialsManagementToolTestCase(TestCase):
         proxy2 = yield self.cred_tool.get_creds_proxy()
         self.assertTrue(proxy1 is proxy2)
 
+    def test_ui_params(self):
+        """The UI_PARAMS dict is correct."""
+        expected = {
+            HELP_TEXT_KEY: DESCRIPTION,
+            PING_URL_KEY: PING_URL,
+            POLICY_URL_KEY: POLICY_URL,
+            TC_URL_KEY: TC_URL,
+            UI_EXECUTABLE_KEY: UI_EXECUTABLE_QT,
+        }
+        self.assertEqual(expected, UI_PARAMS)
+
 
 class ArgsTestCase(CredentialsManagementToolTestCase):
     """Test case to check that proper arguments are passed to SSO backend."""
