@@ -1,8 +1,6 @@
+# -*- encoding: utf-8 -*-
 #
-# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
-#         Manuel de la Pena <manuel@canonical.com>
-#
-# Copyright 2010-2011 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +13,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Test for the  os operations in the platform module."""
 
 import errno
@@ -34,6 +44,7 @@ from ubuntuone.platform import (
     access,
     allow_writes,
     can_write,
+    expand_user,
     is_link,
     listdir,
     make_dir,
@@ -309,6 +320,12 @@ class OSWrapperTests(BaseTestCase):
         """The dir is not there."""
         self.assertFalse(path_exists(os.path.join(self.basedir, 'subdir')))
 
+    def test_path_exist_for_link_without_lnk_extension(self):
+        """Test if the path of a link exist without the lnk extension."""
+        destination = os.path.join(self.basedir, 'destination')
+        make_link(self.testfile, destination)
+        self.assertTrue(path_exists(destination))
+
     def test_make_link(self):
         """The link is properly made."""
         destination = os.path.join(self.basedir, 'destination')
@@ -318,6 +335,27 @@ class OSWrapperTests(BaseTestCase):
         self.assertEqual(os.path.normcase(self.testfile),
                          os.path.normcase(read_link(destination)))
 
+    def _assert_read_link(self, target):
+        """Assert if the target path of the link is correct."""
+        destination = os.path.join(self.basedir, target)
+        make_link(self.testfile, destination)
+
+        target = read_link(destination)
+        self.assertEqual(self.testfile, target)
+
+    def test_links_target_without_lnk_extension(self):
+        """Create a link to self.testfile and then retrieve the link target."""
+        # In windows the .lnk extension should be added automatically
+        # if the extension is not added by make_link, read_link will fail
+        # because Windows is not going to recognize the file as a link
+        target = 'target'
+        self._assert_read_link(target)
+
+    def test_links_target_with_lnk_extension(self):
+        """Create a link to self.testfile and then retrieve the link target."""
+        target = 'target.lnk'
+        self._assert_read_link(target)
+
     def test_movetotrash_file_ok(self):
         """Move a file to trash ok.
 
@@ -344,6 +382,55 @@ class OSWrapperTests(BaseTestCase):
         e = self.assertRaises(OSError, move_to_trash, path)
         self.assertEqual(e.errno, errno.ENOENT)
 
+    def test_expand_user_not_start_with_tilde(self):
+        """Test the expand_user function with an ordinary path."""
+        path = 'userpath'
+        result = expand_user(path)
+        self.assertEqual(path, result)
+
+    def test_expand_user_start_with_tilde_no_backslash(self):
+        """Test the expand_user function with tilde an ordinary path."""
+        path = '~userpath'
+        result = expand_user(path)
+        self.assertEqual(path, result)
+
+    def test_expand_user_double_backslash(self):
+        """Test the expand_user function with double backslash."""
+        path = '~~userpath'
+        result = expand_user(path)
+        self.assertEqual(path, result)
+
+    def test_expand_user_start_with_tilde(self):
+        """Test the expand_user function with a path like: ~/userpath."""
+        path = os.path.join('~', 'userpath')
+        result = expand_user(path)
+        expected = os.path.join(self.home_dir, 'userpath')
+        self.assertEqual(expected, result)
+
+    def test_expand_user_tilde_and_backslash(self):
+        """Test the expand_user function with tilde and backslash."""
+        tilde = '~' + os.path.sep
+        result = expand_user(tilde)
+        expected = self.home_dir + os.path.sep
+        self.assertEqual(expected, result)
+
+    def test_expand_user_only_tilde(self):
+        """Test the expand_user function returns with only tilde input."""
+        tilde = '~'
+        result = expand_user(tilde)
+        self.assertEqual(self.home_dir, result)
+        self.assertFalse(result.endswith(os.path.sep))
+
+    def test_expand_user_fails_if_not_bytes(self):
+        """Test the expand_user function input assertions."""
+        path = u'userpath'
+        self.assertRaises(AssertionError, expand_user, path)
+
+    def test_expand_user_fails_if_not_utf8_encoded(self):
+        """Test the expand_user function input encoding."""
+        path = u'usérpath'.encode('latin-1')
+        self.assertRaises(AssertionError, expand_user, path)
+
 
 class RecursiveMoveTests(BaseTestCase):
     """Tests for os wrapper functions."""
