@@ -2,7 +2,7 @@
 # Authors: Manuel de la Pena <manuel@canonical.com>
 #          Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,8 +15,22 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Test the filesystem notifications on windows."""
 
+import logging
 import os
 import tempfile
 import thread
@@ -24,13 +38,17 @@ import time
 import itertools
 
 from twisted.internet import defer
+from win32file import FILE_NOTIFY_INFORMATION
 
 from contrib.testing.testcase import BaseTwistedTestCase
+from ubuntuone.devtools.handlers import MementoHandler
 from ubuntuone.platform.windows import os_helper
 from ubuntuone.platform.windows.pyinotify import (
     ProcessEvent,
+    IN_CLOSE_WRITE,
+    IN_CREATE,
+    IN_DELETE,
     IN_OPEN,
-    IN_CLOSE_WRITE
 )
 from ubuntuone.platform.windows import filesystem_notifications
 from ubuntuone.platform.windows.filesystem_notifications import (
@@ -45,8 +63,14 @@ from ubuntuone.platform.windows.filesystem_notifications import (
     FILE_NOTIFY_CHANGE_LAST_WRITE,
     FILE_NOTIFY_CHANGE_SECURITY,
     FILE_NOTIFY_CHANGE_LAST_ACCESS,
+    WINDOWS_ACTIONS_NAMES,
 )
 
+#create a rever mapping to use it in the tests.
+REVERSE_WINDOWS_ACTIONS = {}
+for key, value in filesystem_notifications.WINDOWS_ACTIONS.iteritems():
+    REVERSE_WINDOWS_ACTIONS[value] = key
+
 
 class FakeException(Exception):
     """A fake Exception used in tests."""
@@ -96,9 +120,9 @@ class TestWatch(BaseTwistedTestCase):
 
     timeout = 5
 
+    @defer.inlineCallbacks
     def setUp(self):
-        """Set infor for the tests."""
-        super(TestWatch, self).setUp()
+        yield super(TestWatch, self).setUp()
         self.basedir = self.mktemp('test_root')
         self.mask = FILE_NOTIFY_CHANGE_FILE_NAME | \
             FILE_NOTIFY_CHANGE_DIR_NAME | \
@@ -107,15 +131,47 @@ class TestWatch(BaseTwistedTestCase):
             FILE_NOTIFY_CHANGE_LAST_WRITE | \
             FILE_NOTIFY_CHANGE_SECURITY | \
             FILE_NOTIFY_CHANGE_LAST_ACCESS
+        self.memento = MementoHandler()
+        self.memento.setLevel(logging.DEBUG)
+        self.raw_events = []
+        self.paths_checked = []
+        old_is_dir = Watch._path_is_dir
 
+        def file_notify_information_wrapper(buf, data):
+            """Wrapper that gets the events and adds them to the list."""
+            events = FILE_NOTIFY_INFORMATION(buf, data)
+            # we want to append the list because that is what will be logged.
+            # If we use extend we wont have the same logging because it will
+            # group all events in a single lists which is not what the COM API
+            # does.
+            str_events = [(WINDOWS_ACTIONS_NAMES[action], path) for action, path in
+                          events]
+            self.raw_events.append(str_events)
+            return events
+
+        def path_is_dir_wrapper(watch, path):
+            """Wrapper that gets the checked paths."""
+            result = old_is_dir(watch, path)
+            self.paths_checked.append((path, result))
+            return result
+
+        self.patch(filesystem_notifications, 'FILE_NOTIFY_INFORMATION',
+                   file_notify_information_wrapper)
+        self.patch(filesystem_notifications.Watch, '_path_is_dir',
+                   path_is_dir_wrapper)
 
     @defer.inlineCallbacks
-    def _perform_operations(self, path, mask, auto_add, actions, number_events):
+    def _perform_operations(self, path, mask, auto_add, actions,
+                            number_events):
         """Perform the file operations and returns the recorded events."""
         handler = TestCaseHandler(number_events=number_events)
         manager = WatchManager(handler)
         yield manager.add_watch(os_helper.get_windows_valid_path(path), mask,
                           auto_add=auto_add)
+        # change the logger so that we can check the logs if we wanted
+        manager._wdm[0].log.addHandler(self.memento)
+        # clean logger later
+        self.addCleanup(manager._wdm[0].log.removeHandler, self.memento)
         # execution the actions
         actions()
         # process the recorded events
@@ -129,6 +185,10 @@ class TestWatch(BaseTwistedTestCase):
         manager = WatchManager()
         manager.add_watch(os_helper.get_windows_valid_path(path), mask,
                           auto_add=auto_add)
+        # change the logger so that we can check the logs if we wanted
+        manager._wdm[0].log.addHandler(self.memento)
+        # clean logger later
+        self.addCleanup(manager._wdm[0].log.removeHandler, self.memento)
         # execution the actions
         actions()
         # process the recorded events
@@ -136,6 +196,18 @@ class TestWatch(BaseTwistedTestCase):
         events = self.handler.processed_events
         return events
 
+    def _assert_logs(self, events):
+        """Assert the debug logs."""
+        logs = []
+        msg = 'Is path %r a dir? %s'
+        logs.extend([msg % data for data in self.paths_checked])
+        msg = 'Got from ReadDirectoryChangesW %r.'
+        logs.extend([msg % actions for actions in self.raw_events])
+        msg = 'Pushing event %r to processor.'
+        logs.extend([msg % e for e in events])
+        for msg in logs:
+            self.assertTrue(self.memento.check_debug(msg))
+
     @defer.inlineCallbacks
     def test_file_create(self):
         """Test that the correct event is returned on a file create."""
@@ -159,6 +231,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual('.', event.path)
         self.assertEqual(os.path.join(self.basedir, file_name), event.pathname)
         self.assertEqual(0, event.wd)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_dir_create(self):
@@ -179,6 +253,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual('.', event.path)
         self.assertEqual(os.path.join(self.basedir, dir_name), event.pathname)
         self.assertEqual(0, event.wd)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_file_remove(self):
@@ -201,6 +277,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual('.', event.path)
         self.assertEqual(os.path.join(self.basedir, file_name), event.pathname)
         self.assertEqual(0, event.wd)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_dir_remove(self):
@@ -222,6 +300,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual('.', event.path)
         self.assertEqual(os.path.join(self.basedir, dir_name), event.pathname)
         self.assertEqual(0, event.wd)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_file_write(self):
@@ -229,6 +309,9 @@ class TestWatch(BaseTwistedTestCase):
         file_name = os.path.join(self.basedir, 'test_file_write')
         # create the file before recording
         fd = open(file_name, 'w')
+        # clean behind us by removing the file
+        self.addCleanup(os.remove, file_name)
+
         def write_file():
             """Action for the test."""
             fd.write('test')
@@ -244,8 +327,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual('.', event.path)
         self.assertEqual(os.path.join(self.basedir, file_name), event.pathname)
         self.assertEqual(0, event.wd)
-        # clean behind us by removeing the file
-        os.remove(file_name)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_file_moved_to_watched_dir_same_watcher(self):
@@ -269,7 +352,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertFalse(move_from_event.dir)
         self.assertEqual(0x40, move_from_event.mask)
         self.assertEqual('IN_MOVED_FROM', move_from_event.maskname)
-        self.assertEqual(os.path.split(from_file_name)[1], move_from_event.name)
+        self.assertEqual(os.path.split(from_file_name)[1],
+                         move_from_event.name)
         self.assertEqual('.', move_from_event.path)
         self.assertEqual(os.path.join(self.basedir, from_file_name),
             move_from_event.pathname)
@@ -287,6 +371,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual(0, move_to_event.wd)
         # assert that both cookies are the same
         self.assertEqual(move_from_event.cookie, move_to_event.cookie)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_file_moved_to_not_watched_dir(self):
@@ -311,8 +397,11 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual('IN_DELETE', event.maskname)
         self.assertEqual(os.path.split(from_file_name)[1], event.name)
         self.assertEqual('.', event.path)
-        self.assertEqual(os.path.join(self.basedir, from_file_name), event.pathname)
+        self.assertEqual(os.path.join(self.basedir, from_file_name),
+                         event.pathname)
         self.assertEqual(0, event.wd)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_file_move_from_not_watched_dir(self):
@@ -341,6 +430,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual(os.path.join(self.basedir, to_file_name),
             event.pathname)
         self.assertEqual(0, event.wd)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_dir_moved_to_watched_dir_same_watcher(self):
@@ -376,10 +467,13 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual('.', move_to_event.path)
         self.assertEqual(os.path.join(self.basedir, to_dir_name),
             move_to_event.pathname)
-        self.assertEqual(os.path.split(from_dir_name)[1], move_to_event.src_pathname)
+        self.assertEqual(os.path.split(from_dir_name)[1],
+                         move_to_event.src_pathname)
         self.assertEqual(0, move_to_event.wd)
         # assert that both cookies are the same
         self.assertEqual(move_from_event.cookie, move_to_event.cookie)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_dir_moved_to_not_watched_dir(self):
@@ -403,6 +497,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual('.', event.path)
         self.assertEqual(os.path.join(self.basedir, dir_name), event.pathname)
         self.assertEqual(0, event.wd)
+        # assert the logging
+        self._assert_logs(events)
 
     @defer.inlineCallbacks
     def test_dir_move_from_not_watched_dir(self):
@@ -426,7 +522,8 @@ class TestWatch(BaseTwistedTestCase):
         self.assertEqual('IN_CREATE|IN_ISDIR', event.maskname)
         self.assertEqual(os.path.split(from_dir_name)[1], event.name)
         self.assertEqual('.', event.path)
-        self.assertEqual(os.path.join(self.basedir, to_dir_name), event.pathname)
+        self.assertEqual(os.path.join(self.basedir, to_dir_name),
+                         event.pathname)
         self.assertEqual(0, event.wd)
 
     def test_exclude_filter(self):
@@ -436,7 +533,7 @@ class TestWatch(BaseTwistedTestCase):
         # add a watch that will always exclude all actions
         manager.add_watch(os_helper.get_windows_valid_path(self.basedir),
                           self.mask, auto_add=True,
-                          exclude_filter=lambda x: True )
+                          exclude_filter=lambda x: True)
         # execution the actions
         file_name = os.path.join(self.basedir, 'test_file_create')
         open(file_name, 'w').close()
@@ -666,22 +763,94 @@ class TestWatch(BaseTwistedTestCase):
     @defer.inlineCallbacks
     def test_stop_watching_fired_when_watch_thread_finishes(self):
         """The deferred returned is fired when the watch thread finishes."""
-        events = []
         test_path = self.mktemp("another_test_directory")
-        fake_processor = events.append
-        watch = Watch(1, test_path, self.mask, True, fake_processor)
+        watch = Watch(1, test_path, self.mask, True, None)
         yield watch.start_watching()
         self.assertNotEqual(watch._watch_handle, None)
         yield watch.stop_watching()
         self.assertEqual(watch._watch_handle, None)
 
+    def test_is_path_dir_missing_no_subdir(self):
+        """Test when the path does not exist and is no a subdir."""
+        path = u'\\\\?\\C:\\path\\to\\no\\dir'
+        test_path = self.mktemp("test_directory")
+        self.patch(os.path, 'exists', lambda path: False)
+        watch = Watch(1, test_path, self.mask, True, None)
+        self.assertFalse(watch._path_is_dir(path))
+
+    def test_is_path_dir_missing_in_subdir(self):
+        """Test when the path does not exist and is a subdir."""
+        path = u'\\\\?\\C:\\path\\to\\no\\dir'
+        test_path = self.mktemp("test_directory")
+        self.patch(os.path, 'exists', lambda path: False)
+        watch = Watch(1, test_path, self.mask, True, None)
+        watch._subdirs.add(path)
+        self.assertTrue(watch._path_is_dir(path))
+
+    def test_is_path_dir_present_is_dir(self):
+        """Test when the path is present and is dir."""
+        path = u'\\\\?\\C:\\path\\to\\no\\dir'
+        test_path = self.mktemp("test_directory")
+        self.patch(os.path, 'exists', lambda path: True)
+        self.patch(os.path, 'isdir', lambda path: True)
+        watch = Watch(1, test_path, self.mask, True, None)
+        watch._subdirs.add(path)
+        self.assertTrue(watch._path_is_dir(path))
+
+    def test_is_path_dir_present_no_dir(self):
+        """Test when the path is present but not a dir."""
+        path = u'\\\\?\\C:\\path\\to\\no\\dir'
+        test_path = self.mktemp("test_directory")
+        self.patch(os.path, 'exists', lambda path: True)
+        self.patch(os.path, 'isdir', lambda path: False)
+        watch = Watch(1, test_path, self.mask, True, None)
+        watch._subdirs.add(path)
+        self.assertFalse(watch._path_is_dir(path))
+
+    def test_update_subdirs_create_not_present(self):
+        """Test when we update on a create event and not present."""
+        path = u'\\\\?\\C:\\path\\to\\no\\dir'
+        test_path = self.mktemp("test_directory")
+        watch = Watch(1, test_path, self.mask, True, None)
+        watch._update_subdirs(path, REVERSE_WINDOWS_ACTIONS[IN_CREATE])
+        self.assertTrue(path in watch._subdirs)
+
+    def test_update_subdirs_create_present(self):
+        """Test when we update on a create event and is present."""
+        path = u'\\\\?\\C:\\path\\to\\no\\dir'
+        test_path = self.mktemp("test_directory")
+        watch = Watch(1, test_path, self.mask, True, None)
+        watch._subdirs.add(path)
+        old_length = len(watch._subdirs)
+        watch._update_subdirs(path, REVERSE_WINDOWS_ACTIONS[IN_CREATE])
+        self.assertTrue(path in watch._subdirs)
+        self.assertEqual(old_length, len(watch._subdirs))
+
+    def test_update_subdirs_delete_not_present(self):
+        """Test when we delete and is not present."""
+        path = u'\\\\?\\C:\\path\\to\\no\\dir'
+        test_path = self.mktemp("test_directory")
+        watch = Watch(1, test_path, self.mask, True, None)
+        watch._update_subdirs(path, REVERSE_WINDOWS_ACTIONS[IN_DELETE])
+        self.assertTrue(path not in watch._subdirs)
+
+    def test_update_subdirs_delete_present(self):
+        """Test when we delete and is present."""
+        path = u'\\\\?\\C:\\path\\to\\no\\dir'
+        test_path = self.mktemp("test_directory")
+        watch = Watch(1, test_path, self.mask, True, None)
+        watch._subdirs.add(path)
+        watch._update_subdirs(path, REVERSE_WINDOWS_ACTIONS[IN_DELETE])
+        self.assertTrue(path not in watch._subdirs)
+
 
 class TestWatchManager(BaseTwistedTestCase):
     """Test the watch manager."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Set each of the tests."""
-        super(TestWatchManager, self).setUp()
+        yield super(TestWatchManager, self).setUp()
         self.parent_path = u'\\\\?\\C:\\'  # a valid windows path
         self.path = self.parent_path + u'path'
         self.watch = Watch(1, self.path, None, True, None)
@@ -954,9 +1123,10 @@ class FakeGeneralProcessor(object):
 class TestNotifyProcessor(BaseTwistedTestCase):
     """Test the notify processor."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """set up the diffeent tests."""
-        super(TestNotifyProcessor, self).setUp()
+        yield super(TestNotifyProcessor, self).setUp()
         self.processor = NotifyProcessor(None)
         self.general = FakeGeneralProcessor()
         self.processor.general_processor = self.general
@@ -1067,15 +1237,18 @@ class TestNotifyProcessor(BaseTwistedTestCase):
         self.assertEqual(5, len(self.general.called_methods))
         # assert that the ignores are called
         self.assertEqual('is_ignored', self.general.called_methods[0][0])
-        self.assertEqual(held_event.pathname, self.general.called_methods[0][1])
+        self.assertEqual(held_event.pathname,
+                         self.general.called_methods[0][1])
         self.assertEqual('is_ignored', self.general.called_methods[1][0])
         self.assertEqual(event.pathname, self.general.called_methods[1][1])
         # assert that we do request the share_id
-        self.assertEqual('get_path_share_id', self.general.called_methods[2][0])
+        self.assertEqual('get_path_share_id',
+                         self.general.called_methods[2][0])
         self.assertEqual(os.path.split(event.pathname)[0],
                          self.general.called_methods[2][1],
                          'Get the share_id for event')
-        self.assertEqual('get_path_share_id', self.general.called_methods[3][0])
+        self.assertEqual('get_path_share_id',
+                         self.general.called_methods[3][0])
         self.assertEqual(os.path.split(held_event.pathname)[0],
                          self.general.called_methods[3][1],
                          'Get the share_id for held event.')
@@ -1083,7 +1256,8 @@ class TestNotifyProcessor(BaseTwistedTestCase):
         self.assertEqual('eq_push', self.general.called_methods[4][0])
         self.assertEqual('FS_DIR_MOVE', self.general.called_methods[4][1])
         self.assertEqual(event.pathname, self.general.called_methods[4][3])
-        self.assertEqual(held_event.pathname, self.general.called_methods[4][4])
+        self.assertEqual(held_event.pathname,
+                         self.general.called_methods[4][4])
 
     def test_process_IN_MOVED_TO_file(self):
         """Test that the in moved to works as expected."""
@@ -1099,15 +1273,18 @@ class TestNotifyProcessor(BaseTwistedTestCase):
         self.assertEqual(5, len(self.general.called_methods))
         # assert that the ignores are called
         self.assertEqual('is_ignored', self.general.called_methods[0][0])
-        self.assertEqual(held_event.pathname, self.general.called_methods[0][1])
+        self.assertEqual(held_event.pathname,
+                         self.general.called_methods[0][1])
         self.assertEqual('is_ignored', self.general.called_methods[1][0])
         self.assertEqual(event.pathname, self.general.called_methods[1][1])
         # assert that we do request the share_id
-        self.assertEqual('get_path_share_id', self.general.called_methods[2][0])
+        self.assertEqual('get_path_share_id',
+                         self.general.called_methods[2][0])
         self.assertEqual(os.path.split(event.pathname)[0],
                          self.general.called_methods[2][1],
                          'Get the share_id for event')
-        self.assertEqual('get_path_share_id', self.general.called_methods[3][0])
+        self.assertEqual('get_path_share_id',
+                         self.general.called_methods[3][0])
         self.assertEqual(os.path.split(held_event.pathname)[0],
                          self.general.called_methods[3][1],
                          'Get the share_id for held event.')
@@ -1115,7 +1292,8 @@ class TestNotifyProcessor(BaseTwistedTestCase):
         self.assertEqual('eq_push', self.general.called_methods[4][0])
         self.assertEqual('FS_FILE_MOVE', self.general.called_methods[4][1])
         self.assertEqual(event.pathname, self.general.called_methods[4][3])
-        self.assertEqual(held_event.pathname, self.general.called_methods[4][4])
+        self.assertEqual(held_event.pathname,
+                         self.general.called_methods[4][4])
 
     def test_fake_create_event_dir(self):
         """Test that the in moved to works as expected."""
@@ -1152,7 +1330,8 @@ class TestNotifyProcessor(BaseTwistedTestCase):
         self.assertEqual(2, len(self.general.called_methods))
         self.assertEqual('eq_push', self.general.called_methods[0][0])
         self.assertEqual('FS_DIR_DELETE', self.general.called_methods[0][1])
-        self.assertEqual(held_event.pathname, self.general.called_methods[0][2])
+        self.assertEqual(held_event.pathname,
+                         self.general.called_methods[0][2])
         self.assertEqual('eq_push', self.general.called_methods[1][0])
         self.assertEqual('FS_DIR_CREATE', self.general.called_methods[1][1])
         self.assertEqual(event.pathname, self.general.called_methods[1][2])
@@ -1168,7 +1347,8 @@ class TestNotifyProcessor(BaseTwistedTestCase):
         self.assertEqual(3, len(self.general.called_methods))
         self.assertEqual('eq_push', self.general.called_methods[0][0])
         self.assertEqual('FS_FILE_DELETE', self.general.called_methods[0][1])
-        self.assertEqual(held_event.pathname, self.general.called_methods[0][2])
+        self.assertEqual(held_event.pathname,
+                         self.general.called_methods[0][2])
         self.assertEqual('eq_push', self.general.called_methods[1][0])
         self.assertEqual('FS_FILE_CREATE', self.general.called_methods[1][1])
         self.assertEqual(event.pathname, self.general.called_methods[1][2])
@@ -1327,7 +1507,7 @@ class FilesystemMonitorTestCase(BaseTwistedTestCase):
                 """Create a new instance."""
                 self.ancestors = ancestors
 
-        ancestors = ['~', '~\\Pictures', '~\\Pictures\\Home',]
+        ancestors = ['~', '~\\Pictures', '~\\Pictures\\Home', ]
         volume = FakeVolume(ancestors)
         monitor = FilesystemMonitor(None, None)
         added = yield monitor.add_watches_to_udf_ancestors(volume)
