@@ -32,7 +32,6 @@ import errno
 import os
 import shutil
 import sys
-import platform
 
 from twisted.internet import defer
 from twisted.trial.unittest import TestCase
@@ -482,19 +481,10 @@ class TestSystemPaths(TestCase):
 
 
 class TestIsRoot(TestCase):
-
     """Tests for the is_root function."""
 
-    def test_isanadmin_called(self):
-        """Test that shell.IsUserAnAdmin is called."""
-        expected = object()
-        self.patch(os_helper.shell, 'IsUserAnAdmin', lambda: expected)
-        actual = os_helper.is_root()
-        self.assertEqual(expected, actual)
-
-    def test_is_root_on_xp(self):
-        """Test that os_helper.is_root always returns False on XP"""
+    def test_is_root(self):
+        """Test that os_helper.is_root always returns False"""
         expected = False
-        self.patch(platform, "version", "5.1.2600")
         actual = os_helper.is_root()
         self.assertEqual(expected, actual)
