@@ -1,7 +1,6 @@
+# encoding: utf-8
 #
-# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
-#
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -14,7 +13,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""tests for the syncdaemon config module """
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
+"""Tests for the syncdaemon config module."""
+
 from __future__ import with_statement
 
 import logging
@@ -22,18 +35,17 @@ import os
 
 from ConfigParser import ConfigParser
 from twisted.internet import defer
-
-from ubuntuone.platform import open_file, path_exists
+from twisted.trial.unittest import TestCase
 from ubuntu_sso.xdg_base_directory import (
     xdg_data_home,
     xdg_cache_home,
 )
-from ubuntuone.syncdaemon import config
-from contrib.testing.testcase import (
-    BaseTwistedTestCase,
-    environ,
-)
+from ubuntuone.devtools.testcases import skipIfOS
 
+from contrib.testing.testcase import BaseTwistedTestCase
+from ubuntuone import platform
+from ubuntuone.platform import open_file, path_exists
+from ubuntuone.syncdaemon import config
 
 
 class TestConfigBasic(BaseTwistedTestCase):
@@ -201,7 +213,6 @@ class TestConfigBasic(BaseTwistedTestCase):
         self.assertEquals(None, conf.get_throttling_read_limit())
         self.assertEquals(None, conf.get_throttling_write_limit())
 
-
     def test_load_partial_config(self):
         """test loading a partial config file and fallback to defaults"""
         conf_file = os.path.join(self.test_root, 'test_load_config.conf')
@@ -470,6 +481,43 @@ class TestConfigBasic(BaseTwistedTestCase):
         conf.set_max_payload_size(666)
         self.assertEqual(conf.get_max_payload_size(), 666)
 
+    def test_get_memory_pool_limit(self):
+        """Get the memory pool limit."""
+        conf_file = os.path.join(self.test_root, 'test_load_config.conf')
+        with open_file(conf_file, 'w') as fh:
+            fh.write('[__main__]\n')
+            fh.write('memory_pool_limit = 12345\n')
+        conf = config._Config(conf_file)
+        self.assertEqual(conf.get_memory_pool_limit(), 12345)
+
+    def test_set_memory_pool_limit(self):
+        """Set the memory pool limit."""
+        conf_file = os.path.join(self.test_root, 'test_load_config.conf')
+        with open_file(conf_file, 'w') as fh:
+            fh.write('[__main__]\n')
+            fh.write('memory_pool_limit = 12345\n')
+        conf = config._Config(conf_file)
+        conf.set_memory_pool_limit(666)
+        self.assertEqual(conf.get_memory_pool_limit(), 666)
+
+
+class UnicodePathsTestCase(TestCase):
+    """Tests for unicode paths."""
+
+    @skipIfOS('linux2', 'On linux paths are bytes so this test does not apply')
+    def test_get_config_files_path_encoding(self):
+        """Check that get_config_files uses paths in the right encoding."""
+        temp = self.mktemp()
+        fake_path = os.path.join(temp, u"Ñandú")
+        os.makedirs(fake_path)
+        with open(os.path.join(fake_path, config.CONFIG_FILE), "w") as f:
+            f.write("this is a fake config file")
+        fake_load_config_paths = lambda _: [fake_path.encode("utf8")]
+        self.patch(config, "load_config_paths", fake_load_config_paths)
+        config_files = config.get_config_files()
+        branch_config = os.path.join(fake_path, config.CONFIG_FILE)
+        self.assertIn(branch_config, config_files)
+
 
 class ConfigglueParsersTests(BaseTwistedTestCase):
     """Tests for our custom configglue parsers."""
@@ -514,12 +562,12 @@ class XdgHomeParsersTests(BaseTwistedTestCase):
     def test_good_value(self):
         """Test the parser using a good value."""
         homedir = os.path.join('', 'home', 'fake')
-        with environ('HOME', homedir):
-            expected = os.path.join(self.xdg_dir, 'hola', 'mundo')
-            actual = self.parser(self.good_value)
-            self.assertEqual(expected, actual)
-            self.assertIsInstance(actual, str)
-            self.assertNotIsInstance(actual, unicode)
+        self.patch(platform, 'xdg_home', homedir)
+        expected = os.path.join(self.xdg_dir, 'hola', 'mundo')
+        actual = self.parser(self.good_value)
+        self.assertEqual(expected, actual)
+        self.assertIsInstance(actual, str)
+        self.assertNotIsInstance(actual, unicode)
 
     def test_bad_value(self):
         """Test the parser using a bad value."""
@@ -670,8 +718,8 @@ class SyncDaemonConfigParserTests(BaseTwistedTestCase):
         self.cp.parse_all()
         self.assertEqual(self.cp.get('__main__', 'simult_transfers').value, 10)
 
-    def test_max_payload_size(self):
-        """Test default configuration for maximum payload size."""
+    def test_memory_pool_limit(self):
+        """Test default configuration for memory pool limit."""
         self.cp.parse_all()
-        configured = self.cp.get('__main__', 'max_payload_size').value
-        self.assertEqual(configured, 1400)
+        configured = self.cp.get('__main__', 'memory_pool_limit').value
+        self.assertEqual(configured, 200)
