@@ -3,7 +3,7 @@
 # Authors: Facundo Batista <facundo@canonical.com>
 #          Manuel de la Pena <manuel@canonical.com>
 #
-# Copyright 2009-2011 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -16,7 +16,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for the Event Queue part that uses inotify."""
 
 import functools
@@ -24,8 +36,8 @@ import logging
 import os
 
 from twisted.internet import defer, reactor
-from ubuntuone.devtools.testcase import skipIfOS
 from ubuntuone.devtools.handlers import MementoHandler
+from ubuntuone.devtools.testcases import skipIfOS
 
 from contrib.testing.testcase import (
     BaseTwistedTestCase,
@@ -645,7 +657,6 @@ class AncestorsUDFTestCase(BaseTwistedTestCase):
         """Init."""
         yield super(AncestorsUDFTestCase, self).setUp()
         self._deferred = defer.Deferred()
-        self.home_dir = self.mktemp('ubuntuonehacker')
         self.root_dir = self.mktemp('root_dir')
         self.data_dir = self.mktemp('data_dir')
         self.shares_dir = self.mktemp('shares_dir')
@@ -660,11 +671,6 @@ class AncestorsUDFTestCase(BaseTwistedTestCase):
         self.eq.subscribe(self.listener)
         self.addCleanup(self.eq.unsubscribe, self.listener)
 
-        env_var = 'HOME'
-        old_value = os.environ.get(env_var, None)
-        os.environ[env_var] = self.home_dir
-        self.addCleanup(os.environ.__setitem__, env_var, old_value)
-
         # create UDF
         suggested_path = u'~/Documents/Reading/Books/PDFs'
         udf_id, node_id = 'udf_id', 'node_id'
@@ -1381,6 +1387,9 @@ class SignalingTests(BaseTwisted):
                 if path != fromdir:
                     self.finished_error("received a wrong path")
                 else:
+                    # file deletion should remove its watch
+                    self.assertNotIn(path, self.eq.monitor._general_watchs)
+
                     remove_dir(todir)
                     remove_dir(helpdir)
                     self.finished_ok()
@@ -1473,6 +1482,11 @@ class SignalingTests(BaseTwisted):
         todir = os.path.join(self.root_dir, "bar")
         make_dir(fromdir)
 
+        # patch to check proper dir deletion is handled
+        called = []
+        self.patch(self.eq.monitor._processor.general_processor,
+                   'handle_dir_delete', lambda p: called.append(p))
+
         # patch the general processor to ignore all that ends with bar
         self.patch(self.eq.monitor._processor.general_processor, "is_ignored",
                    lambda path: path.endswith("bar"))
@@ -1485,6 +1499,7 @@ class SignalingTests(BaseTwisted):
         # generate the event
         rename(fromdir, todir)
         yield self._deferred
+        self.assertEqual(called, [fromdir])
 
     @defer.inlineCallbacks
     def test_file_moved_from_ignored(self):
@@ -1977,6 +1992,11 @@ class SignalingTests(BaseTwisted):
         yield self._create_udf('vol2', base2)
         self.fs.create(path=base2, share_id='vol2', is_dir=True)
 
+        # patch to check proper dir deletion is handled
+        called = []
+        self.patch(self.eq.monitor._processor.general_processor,
+                   'handle_dir_delete', lambda p: called.append(p))
+
         # working stuff
         moving1 = os.path.join(base1, "test")
         moving2 = os.path.join(base2, "test")
@@ -1993,6 +2013,7 @@ class SignalingTests(BaseTwisted):
         # generate the event
         rename(moving1, moving2)
         yield self._deferred
+        self.assertEqual(called, [moving1])
 
     @defer.inlineCallbacks
     def test_move_file_across_volumes(self):
