@@ -1,7 +1,7 @@
 #
 # Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
 #
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -14,8 +14,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
+"""Test file based persistent shelf."""
 
-""" Test file based persistent shelf """
 from __future__ import with_statement
 
 import cPickle
@@ -24,8 +37,9 @@ import hashlib
 import unittest
 
 from twisted.internet import defer
+from ubuntuone.devtools.testcases import skipIfOS
 
-from ubuntuone.devtools.testcase import skipIfOS
+from contrib.testing.testcase import BaseTwistedTestCase
 from ubuntuone.platform import (
     open_file,
     path_exists,
@@ -36,7 +50,6 @@ from ubuntuone.syncdaemon.file_shelf import (
     LRUCache,
     CacheInconsistencyError,
 )
-from contrib.testing.testcase import BaseTwistedTestCase
 
 
 BROKEN_PICKLE = '\axb80\x02}q\x01(U\x01aU\x04testq\x02U\x01bU\x06brokenq\x03u.'
