@@ -1,8 +1,6 @@
-# Author: Facundo Batista <facundo@canonical.com>
-# Author: Natalia Bidart <natalia.bidart@canonical.com>
-# Author: Manuel de la Pena <manuel@canonical.com>
+# -*- coding: utf-8 -*-
 #
-# Copyright 2009-2011 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +13,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for the Local Re-scanner."""
 
 from __future__ import with_statement
@@ -26,7 +36,7 @@ import uuid
 
 from twisted.internet import defer, reactor
 from ubuntuone.devtools.handlers import MementoHandler
-from ubuntuone.devtools.testcase import skipIfOS
+from ubuntuone.devtools.testcases import skipIfOS
 
 from contrib.testing.testcase import (
     BaseTwistedTestCase,
@@ -55,6 +65,10 @@ from ubuntuone.syncdaemon.tritcask import Tritcask
 from ubuntuone.storageprotocol import (
     content_hash as storage_hash, volumes
 )
+from ubuntuone.syncdaemon.volume_manager import (
+    ACCESS_LEVEL_RO,
+    ACCESS_LEVEL_RW,
+)
 
 # our logging level
 TRACE = logging.getLevelName('TRACE')
@@ -118,18 +132,12 @@ class BaseTestCase(BaseTwistedTestCase):
     def setUp(self):
         """ Setup the test """
         yield super(BaseTestCase, self).setUp()
-        self.home_dir = self.mktemp('ubuntuonehacker')
         self.shares_dir = self.mktemp('shares')
         usrdir = self.mktemp("usrdir")
         self.fsmdir = self.mktemp("fsmdir")
         self.partials_dir = self.mktemp("partials")
         self.tritcask_dir = self.mktemp("tritcask")
 
-        # set the home for the tests
-        old_value = os.environ.get('HOME', None)
-        os.environ['HOME'] = self.home_dir
-        self.addCleanup(os.environ.__setitem__, 'HOME', old_value)
-
         self.vm = FakeVolumeManager(usrdir)
         self.db = Tritcask(self.tritcask_dir)
         self.addCleanup(self.db.shutdown)
@@ -143,11 +151,11 @@ class BaseTestCase(BaseTwistedTestCase):
 
     @defer.inlineCallbacks
     def create_share(self, share_id, share_name,
-                     access_level='Modify', accepted=True, subscribed=True):
+                     access_level=ACCESS_LEVEL_RW, accepted=True, subscribed=True):
         """Create a share."""
         assert isinstance(share_name, unicode)
 
-        share_path = os.path.join(self.shares_dir, share_name.encode('utf8'))
+        share_path = os.path.join(self.shares_dir, share_name.encode('utf-8'))
         make_dir(share_path, recursive=True)
         share = volume_manager.Share(path=share_path, volume_id=share_id,
                                      access_level=access_level,
@@ -224,7 +232,7 @@ class CollectionTests(BaseTestCase):
         """Test with one empty Modify share."""
         # create the share
         share = yield self.create_share('share_id', u'rw_share',
-                                        access_level='Modify')
+                                        access_level=ACCESS_LEVEL_RW)
         self.fsm.create(share.path, "share_id", is_dir=True)
         self.fsm.set_node_id(share.path, "uuid")
 
@@ -245,7 +253,7 @@ class CollectionTests(BaseTestCase):
         """Test with a Modify share with info."""
         # create the share
         share = yield self.create_share('share_id', u'ro_share',
-                                        access_level='Modify')
+                                        access_level=ACCESS_LEVEL_RW)
         self.fsm.create(share.path, "share_id", is_dir=True)
         self.fsm.set_node_id(share.path, "uuid1")
 
@@ -272,7 +280,7 @@ class CollectionTests(BaseTestCase):
         """Test with a deleted rw share."""
         # create the share
         share = yield self.create_share('share_id', u'rw_share',
-                                        access_level='Modify')
+                                        access_level=ACCESS_LEVEL_RW)
         self.fsm.create(share.path, "share_id", is_dir=True)
         self.fsm.set_node_id(share.path, "uuid")
 
@@ -301,7 +309,7 @@ class CollectionTests(BaseTestCase):
         """Test with a deleted rw share with some nodes in it."""
         # create the share
         share = yield self.create_share('share_id', u'rw_share',
-                                        access_level='Modify')
+                                        access_level=ACCESS_LEVEL_RW)
         self.fsm.create(share.path, "share_id", is_dir=True)
         self.fsm.set_node_id(share.path, "uuid")
 
@@ -368,10 +376,6 @@ class VolumeTestCase(BaseTestCase):
         """Init."""
         yield super(VolumeTestCase, self).setUp()
 
-        old_value = os.environ.get('HOME', None)
-        os.environ['HOME'] = self.home_dir
-        self.addCleanup(os.environ.__setitem__, 'HOME', old_value)
-
         self.lr = local_rescan.LocalRescan(self.vm, self.fsm, self.eq, self.aq)
 
         self.volumes = []
@@ -516,7 +520,7 @@ class TwistedBase(BaseTestCase):
 
         # create a share
         self.share = yield self.create_share('share_id', u'ro_share',
-                                             access_level='Modify')
+                                             access_level=ACCESS_LEVEL_RW)
         self.fsm.create(self.share.path, "share_id", is_dir=True)
         self.fsm.set_node_id(self.share.path, "uuidshare")
         self.share.node_id = "uuidshare"
@@ -634,30 +638,30 @@ class ComparationTests(TwistedBase):
                        "can't make this explode there")
     @defer.inlineCallbacks
     def test_disc_non_utf8_file(self):
-        """Test having a utf8 file."""
+        """Test having a utf-8 file."""
         # create a broken path
-        path = os.path.join(self.share.path, "non utf8 \xff path")
+        path = os.path.join(self.share.path, "non utf-8 \xff path")
         with open_file(path, "w") as fh:
             fh.write("broken")
 
         yield self.lr.start()
         self.assertEqual(self.eq.pushed, [])
         self.assertTrue(self.handler.check_info("Ignoring path",
-                                                "invalid (non utf8)"))
+                                                "invalid (non utf-8)"))
 
     @skipIfOS('win32', "Windows paths are already unicode, "
                        "can't make this explode there")
     @defer.inlineCallbacks
     def test_disc_non_utf8_dir(self):
-        """Test having a utf8 dir."""
+        """Test having a utf-8 dir."""
         # create a broken path
-        path = os.path.join(self.share.path, "non utf8 \xff path")
+        path = os.path.join(self.share.path, "non utf-8 \xff path")
         make_dir(path)
 
         yield self.lr.start()
         self.assertEqual(self.eq.pushed, [])
         self.assertTrue(self.handler.check_info("Ignoring path",
-                                                "invalid (non utf8)"))
+                                                "invalid (non utf-8)"))
 
     @defer.inlineCallbacks
     def test_disc_more_dir_normal(self):
@@ -948,7 +952,7 @@ class ComparationTests(TwistedBase):
         """The dir is in a share that's RO, no error but no action."""
         # create the share
         share = yield self.create_share('share_id', u'ro_share2',
-                                        access_level='View')
+                                        access_level=ACCESS_LEVEL_RO)
         self.fsm.create(share.path, "share_id", is_dir=True)
         self.fsm.set_node_id(share.path, "uuidshare")
 
@@ -1171,11 +1175,11 @@ class QueuingTests(BaseTestCase):
 
         # create two shares
         self.share1 = yield self.create_share('share_id1', u'ro_share_1',
-                                              access_level='Modify')
+                                              access_level=ACCESS_LEVEL_RW)
         self.fsm.create(self.share1.path, "share_id1", is_dir=True)
         self.fsm.set_node_id(self.share1.path, "uuidshare1")
         self.share2 = yield self.create_share('share_id2', u'ro_share_2',
-                                              access_level='Modify')
+                                              access_level=ACCESS_LEVEL_RW)
         self.fsm.create(self.share2.path, "share_id2", is_dir=True)
         self.fsm.set_node_id(self.share2.path, "uuidshare2")
 
@@ -1529,8 +1533,6 @@ class BadStateTests(TwistedBase):
                          (mdobj.share_id, mdobj.node_id, mdobj.server_hash,
                           mdobj.local_hash, mdobj.crc32, mdobj.size, path))
         self.assertEqual(self.aq.uploaded[1], {'upload_id':None})
-        factory = self.aq.uploaded[0][-1]
-        self.assertTrue(isinstance(factory(), file))
         self.assertTrue(self.handler.check_debug("resuming upload",
                                                  "interrupted"))
 
@@ -1580,8 +1582,6 @@ class BadStateTests(TwistedBase):
                          (mdobj.share_id, mdobj.node_id, mdobj.server_hash,
                           mdobj.local_hash, mdobj.crc32, mdobj.size, path))
         self.assertEqual(self.aq.uploaded[1], {'upload_id':'hola'})
-        factory = self.aq.uploaded[0][-1]
-        self.assertTrue(isinstance(factory(), file))
         self.assertTrue(self.handler.check_debug("resuming upload",
                                                  "interrupted"))
 
@@ -1609,8 +1609,6 @@ class BadStateTests(TwistedBase):
         self.assertEqual(self.aq.downloaded[:4],
                          (mdobj.share_id, mdobj.node_id,
                           mdobj.server_hash, path))
-        factory = self.aq.downloaded[-1]
-        self.assertTrue(isinstance(factory(), file))
         self.assertTrue(self.handler.check_debug("comp yield", "SERVER"))
 
     @defer.inlineCallbacks
@@ -1635,8 +1633,6 @@ class BadStateTests(TwistedBase):
         self.assertEqual(self.aq.downloaded[:4],
                          (mdobj.share_id, mdobj.node_id,
                           mdobj.server_hash, path))
-        factory = self.aq.downloaded[-1]
-        self.assertTrue(isinstance(factory(), file))
         self.assertTrue(self.handler.check_debug("comp yield", "SERVER"))
 
     @defer.inlineCallbacks
@@ -1939,7 +1935,7 @@ class BadStateTests(TwistedBase):
         """We were downloading the file, but it was interrupted in RO share."""
         # create the file in metadata
         ro_share = yield self.create_share('share_ro_id', u'share_ro2',
-                                           access_level='View')
+                                           access_level=ACCESS_LEVEL_RO)
         self.fsm.create(ro_share.path, ro_share.id, is_dir=True)
         self.fsm.set_node_id(ro_share.path, "uuidshare")
         path = os.path.join(ro_share.path, "a")
@@ -1963,8 +1959,6 @@ class BadStateTests(TwistedBase):
         self.assertEqual(self.aq.downloaded[:4],
                          (mdobj.share_id, mdobj.node_id,
                           mdobj.server_hash, path))
-        factory = self.aq.downloaded[-1]
-        self.assertTrue(isinstance(factory(), file))
         self.assertTrue(self.handler.check_debug("comp yield", "SERVER"))
 
     @defer.inlineCallbacks
@@ -1975,7 +1969,7 @@ class BadStateTests(TwistedBase):
         """
         # create the dir in metadata
         ro_share = yield self.create_share('share_ro_id', u'share_ro2',
-                                           access_level='View')
+                                           access_level=ACCESS_LEVEL_RO)
         self.fsm.create(ro_share.path, ro_share.id, is_dir=True)
         self.fsm.set_node_id(ro_share.path, "uuidshare")
 
@@ -2014,13 +2008,6 @@ class BadStateTests(TwistedBase):
 class RootBadStateTests(TwistedBase):
     """Test what happens with volume roots left in a bad state last time."""
 
-    @defer.inlineCallbacks
-    def setUp(self):
-        yield super(RootBadStateTests, self).setUp()
-        old_value = os.environ.get('HOME', None)
-        os.environ['HOME'] = self.home_dir
-        self.addCleanup(os.environ.__setitem__, 'HOME', old_value)
-
     @defer.inlineCallbacks
     def _test_it(self, volume):
         """Run the bad state test for a specific volume."""
@@ -2056,7 +2043,7 @@ class RootBadStateTests(TwistedBase):
         """We were downloading the share root dir but it was interrupted."""
         # create a share
         share = yield self.create_share('share_id_1', u'rw_share',
-                                        access_level='Modify')
+                                        access_level=ACCESS_LEVEL_RW)
         self.fsm.create(share.path, "share_id_1", is_dir=True)
         self.fsm.set_node_id(share.path, "uuid_share_1")
         share.node_id = "uuid_share_1"
@@ -2258,10 +2245,6 @@ class ParentWatchForUDFTestCase(BaseTestCase):
 
         self.lr = local_rescan.LocalRescan(self.vm, self.fsm, self.eq, self.aq)
 
-        old_value = os.environ.get('HOME', None)
-        os.environ['HOME'] = self.home_dir
-        self.addCleanup(os.environ.__setitem__, 'HOME', old_value)
-
         # create UDF
         suggested_path = u'~/Documents/Reading/Books/PDFs'
         udf_id, node_id = 'udf_id', 'node_id'
