@@ -2,7 +2,7 @@
 #
 # Author: Facundo Batista <facundo@canonical.com>
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,6 +15,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """ ActionQueue tests """
 
 import logging
@@ -260,6 +273,21 @@ class LockingTests(TwistedTestCase):
         releases.pop(0)()
         yield d3
 
+    def test_deferred_can_be_cancelled(self):
+        """The path locking can be cancelled without harm."""
+        releases = []
+        d1 = self.plt.acquire("path")
+        d1.addCallback(lambda _: releases.append(1))
+        d2 = self.plt.acquire("path")
+        d2.addCallback(lambda _: releases.append(2))
+
+        # the first one should not be locked
+        self.assertEqual(releases, [1])
+
+        # cancel the second deferred, but it still needs to pass ok
+        d2.cancel()
+        self.assertEqual(releases, [1, 2])
+
     @defer.inlineCallbacks
     def test_same_path_having_parent(self):
         """Lock with parent having just the parent."""
@@ -560,7 +588,10 @@ class LoggingTests(TwistedTestCase):
         self.plt = PathLockingTree()
 
         self.handler = MementoHandler()
+        self.plt.logger.setLevel(logging.DEBUG)
+        self.plt.logger.propagate = False
         self.plt.logger.addHandler(self.handler)
+        self.addCleanup(self.plt.logger.removeHandler, self.handler)
 
     @defer.inlineCallbacks
     def test_logger_can_be_given(self):
@@ -568,6 +599,8 @@ class LoggingTests(TwistedTestCase):
         logger = logging.getLogger("ubuntuone.SyncDaemon.Test")
         handler = MementoHandler()
         logger.addHandler(handler)
+        logger.setLevel(logging.DEBUG)
+        logger.propagate = False
 
         # acquire and test
         release = yield self.plt.acquire('path', logger=logger)
