@@ -214,6 +214,16 @@ class _GeneralINotifyProcessor(pyinotify.ProcessEvent):
         if not (event.mask & pyinotify.IN_ISDIR):
             self.general_processor.push_event(event)
 
+    @validate_filename
+    def process_IN_CLOSE_WRITE(self, event):
+        """Filter IN_CLOSE_WRITE to make it happen only in files.
+
+        eCryptFS sends IN_CLOSE_WRITE event for lower directories.
+
+        """
+        if not (event.mask & pyinotify.IN_ISDIR):
+            self.general_processor.push_event(event)
+
     def process_IN_MOVE_SELF(self, event):
         """Don't do anything here.
 
