@@ -2,7 +2,7 @@
 #
 # Author: Lucio Torre <lucio.torre@canonical.com>
 #
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,8 +15,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-"""Linux import for ubuntuone-client
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
+"""
+Linux import for ubuntuone-client
 
 This module has to have all linux specific modules and provide the api required
 to support the linux platform.
@@ -29,7 +42,7 @@ import shutil
 import stat
 import sys
 
-if 'gobject' in sys.modules:
+if 'gobject' in sys.modules and sys.modules['gobject'] is not None:
     import gio
     has_gi = False
 else:
@@ -115,6 +128,11 @@ def rename(path_from, path_to):
     os.rename(path_from, path_to)
 
 
+def native_rename(path_from, path_to):
+    """Rename a file or directory."""
+    os.rename(path_from, path_to)
+
+
 def recursive_move(path_from, path_to):
     """Perform a recursive move."""
     shutil.move(path_from, path_to)
@@ -205,6 +223,7 @@ def set_application_name(app_name):
         import gobject
         gobject.set_application_name(app_name)
 
+
 def is_root():
     """Return if the user is running as root."""
     return not os.geteuid()
