@@ -1,9 +1,6 @@
 # ubuntuone.platform.windows - windows platform imports
 #
-# Author: Lucio Torre <lucio.torre@canonical.com>
-#         Manuel de la Pena <manuel@canonical.com>
-#
-# Copyright 2010-11 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -16,7 +13,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""Windows import for ubuntuone-client
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
+"""
+Windows import for ubuntuone-client
 
 This module has to have all windows specific modules and provide the api
 required to support the windows platform.
@@ -25,6 +36,16 @@ required to support the windows platform.
 platform = "win32"
 
 
+import constants
+import event_logging
+import filesystem_notifications
+import launcher
+import logger
+import messaging
+import notification
+import os_helper
+import session
+
 from ubuntuone.platform.windows.os_helper import (
     access,
     allow_writes,
@@ -36,6 +57,7 @@ from ubuntuone.platform.windows.os_helper import (
     make_dir,
     make_link,
     move_to_trash,
+    native_rename,
     normpath,
     open_file,
     path_exists,
@@ -58,44 +80,14 @@ from ubuntuone.platform.windows.os_helper import (
 from ubuntuone.platform.windows import event_logging
 from ubuntuone.platform.windows.logger import (
     setup_filesystem_logging,
-    get_filesystem_logger)
+    get_filesystem_logger,
+)
 from ubuntuone.platform.windows.filesystem_notifications import (
-    FilesystemMonitor)
-from ubuntuone.platform.windows.notification import Notification
-
-
-def is_already_running():
-    """An ugly workaround for circular imports, see bug #817559."""
-    from ubuntuone.platform.windows.ipc import is_already_running
-    return is_already_running()
-
-
-class ExternalInterface(object):
-    """An ExternalInterface implemented with a IPC interface."""
-
-    def __init__(self, main, glib_loop=False, broadcast_events=False,
-                 dbus_iface=None):
-        """Create an instance using the same params as in Linux."""
-
-        if dbus_iface is None:
-            from ubuntuone.platform.windows import ipc
-            self.dbus_iface = ipc.IPCInterface(main,
-                                               send_events=broadcast_events)
-
-        else:
-            self.dbus_iface = dbus_iface
-            self.bus = None
-
-    def _get_credentials(self):
-        return self.dbus_iface.oauth_credentials
-
-    def _set_credentials(self, credentials):
-        self.dbus_iface.oauth_credentials = credentials
-
-    oauth_credentials = property(fget=_get_credentials, fset=_set_credentials)
-
-    def shutdown(self, with_restart):
-        self.dbus_iface.shutdown(with_restart)
-
-    def connect(self, *args, **kwargs):
-        self.dbus_iface.connect(*args, **kwargs)
+    FilesystemMonitor,
+    NotifyProcessor as _GeneralINotifyProcessor,
+)
+from ubuntuone.platform.windows import notification
+from ubuntuone.platform.windows.ipc import (
+    IPCInterface as ExternalInterface,
+    is_already_running,
+)
