@@ -759,6 +759,10 @@ class UbuntuOneClient(object):
                             'Could not connect to the syncdaemon ipc.', e)
         # pylint: disable=W0702
 
+    def is_connected(self):
+        """Return if the client is connected."""
+        return (self.client is not None)
+
     @defer.inlineCallbacks
     def register_to_signals(self):
         """Register the different clients to the signals."""
