@@ -1,7 +1,6 @@
-# Authors: Manuel de la Pena <manuel@canonical.com>
-#          Natalia B. Bidart <natalia.bidart@canonical.com>
+# -*- encoding: utf-8 -*-
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -14,7 +13,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Windows tools to interact with the os."""
 
 import errno
@@ -32,12 +43,14 @@ from ntsecuritycon import (
     FILE_GENERIC_WRITE,
     FILE_ALL_ACCESS,
 )
+import win32api
 from pywintypes import error as PyWinError
-from win32api import GetUserName
 from win32com.client import Dispatch
 from win32com.shell import shell, shellcon
 from win32file import (
+    GetFileAttributesW,
     MoveFileExW,
+    FILE_ATTRIBUTE_SYSTEM,
     MOVEFILE_COPY_ALLOWED,
     MOVEFILE_REPLACE_EXISTING,
     MOVEFILE_WRITE_THROUGH,
@@ -49,13 +62,20 @@ from win32security import (
     CreateWellKnownSid,
     DACL_SECURITY_INFORMATION,
     GetFileSecurity,
+    GetSecurityInfo,
     LookupAccountName,
     OBJECT_INHERIT_ACE,
+    OWNER_SECURITY_INFORMATION,
     SetFileSecurity,
+    SE_KERNEL_OBJECT,
     WinBuiltinAdministratorsSid,
     WinWorldSid,
 )
 
+from comtypes import shelllink
+from comtypes.client import CreateObject
+from comtypes.persist import IPersistFile
+
 # ugly trick to stop pylint for complaining about
 # WindowsError on Linux
 if sys.platform != 'win32':
@@ -65,11 +85,13 @@ if sys.platform != 'win32':
 logger = logging.getLogger('ubuntuone.SyncDaemon.VM')
 platform = 'win32'
 
+# missing win32file constant
+INVALID_FILE_ATTRIBUTES = -1
+
 # LONG_PATH_PREFIX will always be appended only to windows paths,
 # which should always be unicode.
 LONG_PATH_PREFIX = u'\\\\?\\'
 
-USER_SID = LookupAccountName("", GetUserName())[0]
 EVERYONE_SID = CreateWellKnownSid(WinWorldSid)
 ADMINISTRATORS_SID = CreateWellKnownSid(WinBuiltinAdministratorsSid)
 
@@ -93,6 +115,16 @@ for key, value in WINDOWS_ILLEGAL_CHARS_MAP.iteritems():
     LINUX_ILLEGAL_CHARS_MAP[value] = key
 
 
+def get_user_sid():
+    process_handle = win32api.GetCurrentProcess()
+    security_info = GetSecurityInfo(process_handle, SE_KERNEL_OBJECT,
+                                    OWNER_SECURITY_INFORMATION)
+    return security_info.GetSecurityDescriptorOwner()
+
+
+USER_SID = get_user_sid()
+
+
 def _int_to_bin(n):
     """Convert an int to a bin string of 32 bits."""
     return "".join([str((n >> y) & 1) for y in range(32 - 1, -1, -1)])
@@ -156,7 +188,8 @@ def assert_syncdaemon_path(path, method_name=None):
         'byte_path': 'Path %r should be a bytes sequence.',
         'utf8_path': 'Path %r should be encoded with utf8.',
         'long_path': '%r should not start with the LONG_PATH_PREFIX.',
-        'unicode_chars': '%r should not contain any character from LINUX_ILLEGAL_CHARS_MAP.',
+        'unicode_chars': '%r should not contain any character from '
+                         'LINUX_ILLEGAL_CHARS_MAP.',
     }
     messages = _add_method_info(messages, method_name)
 
@@ -381,9 +414,9 @@ def syncdamonpath(path_indexes=None):
     """Decorator to validate and transform path parameters.
 
     The paths given by the indexes from 'path_indexes' are validated to be
-    'syncdaemon' paths,  and are also transformed to be valid 'syncdaemon' path,
-    using the get_syncdaemon_valid_path transformer. If 'path_indexes' is None,
-    only the first argument is checked.
+    'syncdaemon' paths,  and are also transformed to be valid 'syncdaemon'
+    path, using the get_syncdaemon_valid_path transformer. If 'path_indexes'
+    is None, only the first argument is checked.
 
 
     """
@@ -416,7 +449,7 @@ def _has_read_mask(number):
 def _set_file_attributes(path, groups):
     """Set file attributes using the wind32api."""
     if not os.path.exists(path):
-        raise WindowsError('Path %s could not be found.' % path)
+        raise WindowsError(errno.ENOENT, 'Path %s could not be found.' % path)
 
     # No need to do any specific handling for invalid characters since
     # 'path' is a valid windows path.
@@ -547,7 +580,7 @@ def remove_dir(path):
 @windowspath()
 def path_exists(path):
     """Return if the path exists."""
-    return os.path.exists(path)
+    return os.path.exists(path) or native_is_link(path)
 
 
 @windowspath()
@@ -568,16 +601,16 @@ def open_file(path, mode='r'):
 @windowspath(path_indexes=[0, 1])
 def rename(path_from, path_to):
     """Rename a file or directory."""
-    return _rename(path_from, path_to)
+    return native_rename(path_from, path_to)
 
 
-def _rename(path_from, path_to):
-    """Rename a file or directory."""
+def native_rename(path_from, path_to):
+    """Rename a file or directory, using native paths."""
     # No need to do any specific handling for invalid characters since
     # 'path_from' and 'path_to' are valid windows paths.
-    # Also, to ensure the same behaviors as on linux, use the MoveFileExW function
-    # from win32 which will allow to replace the destination path if exists
-    # and the user has the proper rights. For further information, see:
+    # Also, to ensure the same behaviors as on linux, use the MoveFileExW
+    # function from win32 which will allow to replace the destination path if
+    # exists and the user has the proper rights. For further information, see:
     # http://msdn.microsoft.com/en-us/library/aa365240(v=vs.85).aspx
     flag = MOVEFILE_COPY_ALLOWED | \
            MOVEFILE_WRITE_THROUGH | \
@@ -598,7 +631,7 @@ def recursive_move(path_from, path_to):
         if os.path.isdir(path_to):
             path_to = os.path.join(path_to, os.path.basename(path_from))
         try:
-            _rename(path_from, path_to)
+            native_rename(path_from, path_to)
         except OSError, e:
             raise IOError(e.errno, str(e))
     else:
@@ -621,11 +654,12 @@ def make_link(target, destination):
     destination = destination.replace(LONG_PATH_PREFIX, u'')
     target = target.replace(LONG_PATH_PREFIX, u'')
 
-    shell_script = Dispatch('WScript.Shell')
     try:
-        shortcut = shell_script.CreateShortCut(destination)
-        shortcut.Targetpath = target
-        shortcut.save()
+        shortcut = CreateObject(shelllink.ShellLink)
+        shortcut.SetPath(target)
+        shortcut.SetWorkingDirectory(target)
+        pf = shortcut.QueryInterface(IPersistFile)
+        pf.Save(destination, True)
     except:
         logger.exception('make_link could not be completed for target %r, '
                          'destination %r:', target, destination)
@@ -636,22 +670,43 @@ def make_link(target, destination):
 @windowspath()
 def read_link(path):
     """Read the destination of a link."""
+    # THIS SHOULD BE FIXED IN ORDER TO SUPPORT THE PROPER API
+    # The workaround to support unicode paths was to use: WorkingDirectory,
+    # because TargetPath or anything related was returning malformed paths.
+    # The bug associated to this issue is: #907336
+    # https://bugs.launchpad.net/ubuntuone-client/+bug/907336
     if not path.endswith(u'.lnk'):
         path += u'.lnk'
-    shell_script = Dispatch('WScript.Shell')
-    shortcut = shell_script.CreateShortCut(path)
-    result = get_syncdaemon_valid_path(LONG_PATH_PREFIX + shortcut.Targetpath)
+    shortcut = CreateObject(shelllink.ShellLink)
+    pf = shortcut.QueryInterface(IPersistFile)
+    pf.Load(path, True)
+    target_path = shortcut.GetWorkingDirectory().encode('utf-8')
+    target_path = target_path.decode('utf-8')
+    result = get_syncdaemon_valid_path(LONG_PATH_PREFIX + target_path)
     return result
 
 
 @windowspath()
 def is_link(path):
     """Returns if a path is a link or not."""
+    return native_is_link(path)
+
+
+def native_is_link(path):
+    """Check if a file is a link, using native paths."""
     if not path.endswith('.lnk'):
         path += '.lnk'
     return os.path.exists(path)
 
 
+def native_is_system_path(path):
+    """Return if the path has the sys attr."""
+    attrs = GetFileAttributesW(path)
+    if attrs == INVALID_FILE_ATTRIBUTES:
+        return False
+    return FILE_ATTRIBUTE_SYSTEM & attrs == FILE_ATTRIBUTE_SYSTEM
+
+
 @windowspath()
 def remove_link(path):
     """Removes a link."""
@@ -685,7 +740,12 @@ def listdir(directory):
     if not directory.endswith(os.path.sep):
         directory += os.path.sep
 
-    return map(_unicode_to_bytes, os.listdir(directory))
+    # On top of the above we have the issue in which python os.listdir does
+    # return those paths that are system paths. Those paths are the ones that
+    # we do not want to work with.
+
+    return map(_unicode_to_bytes, [p for p in os.listdir(directory) if not
+        native_is_system_path(os.path.join(directory, p))])
 
 
 @windowspath()
@@ -700,10 +760,17 @@ def walk(path, topdown=True):
     handled.
 
     """
+    # Interestingly, while os.listdir DOES return the system folders, os.walk
+    # does not. Nevertheless lets filter the same way in here so that if python
+    # os.walk changes at some point, we do the same in BOTH methods.
     for dirpath, dirnames, filenames in os.walk(path, topdown):
         dirpath = _unicode_to_bytes(dirpath.replace(LONG_PATH_PREFIX, u''))
-        dirnames = map(_unicode_to_bytes, dirnames)
-        filenames = map(_unicode_to_bytes, filenames)
+        if native_is_system_path(dirpath):
+            continue
+        dirnames = map(_unicode_to_bytes, [p for p in dirnames if
+             not native_is_system_path(os.path.join(dirpath, p))])
+        filenames = map(_unicode_to_bytes, [p for p in filenames if not
+                native_is_system_path(os.path.join(dirpath, p))])
         yield dirpath, dirnames, filenames
 
 
@@ -795,9 +862,9 @@ def move_to_trash(path):
     # It is good practice to examine the value of the fAnyOperationsAborted
     # member of the SHFILEOPSTRUCT. SHFileOperation can return 0 for success if
     # the user cancels the operation. If you do not check fAnyOperationsAborted
-    # as well as the return value, you cannot know that the function accomplished
-    # the full task you asked of it and you might proceed under incorrect
-    # assumptions.
+    # as well as the return value, you cannot know that the function
+    # accomplished the full task you asked of it and you might proceed
+    # under incorrect assumptions.
 
     code, aborted = result
     if code != 0 or aborted:
@@ -817,7 +884,10 @@ def set_application_name(app_name):
 
 def is_root():
     """Return if the user is running as root."""
-    # TODO: Do check if we are running as admin
+    # Always return False. Trying to be smart about OS versions and 
+    # only calling Windows APIs under certain conditions has still
+    # proven not to work in some cases. Overall it should not matter
+    # if we know whether we are Administrator or not on Windows.
     return False
 
 
