@@ -40,7 +40,9 @@ class RawOutputFormat:
         self.format = format or {}
 
     def simple(self, s, attribute):
-        if not isinstance(s, str):
+        if isinstance(s, unicode):
+            s = s.encode('mbcs', 'replace')
+        else:
             s = str(s)
         return (self.format.get(attribute, '') + s +
                 self.format.get('normal', ''))
