@@ -2,7 +2,7 @@
 #
 # Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,6 +15,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Aggregate status events."""
 
 import itertools
@@ -28,8 +41,7 @@ from twisted.internet import reactor, defer
 
 from ubuntuone.clientdefs import GETTEXT_PACKAGE
 from ubuntuone.status.logger import logger
-from ubuntuone.platform import session
-from ubuntuone.platform.notification import Notification
+from ubuntuone.platform import session, notification
 from ubuntuone.platform.messaging import Messaging
 from ubuntuone.platform.launcher import UbuntuOneLauncher, DummyLauncher
 
@@ -127,7 +139,7 @@ class ToggleableNotification(object):
     def __init__(self, notification_switch):
         """Initialize this instance."""
         self.notification_switch = notification_switch
-        self.notification = Notification()
+        self.notification = notification.Notification()
 
     def send_notification(self, *args):
         """Passthru the notification."""
@@ -766,13 +778,13 @@ class StatusAggregator(object):
         logger.debug("unqueueing command: %s", command.__class__.__name__)
         self.update_progressbar()
 
-    def progress_made(self, share_id, node_id, n_bytes_written, deflated_size):
+    def progress_made(self, share_id, node_id, n_bytes, deflated_size):
         """Progress made on up- or download."""
-        if n_bytes_written is not None:
+        if n_bytes is not None:
             # if we haven't gotten the total size yet, set it now
             if deflated_size and (share_id, node_id) not in self.to_do:
                 self.to_do[(share_id, node_id)] = deflated_size
-            self.progress[(share_id, node_id)] = n_bytes_written
+            self.progress[(share_id, node_id)] = n_bytes
         self.update_progressbar()
 
     def connection_lost(self):
@@ -821,10 +833,10 @@ class StatusFrontend(object):
         """A file upload was unqueued."""
         self.aggregator.upload_finished(command)
 
-    def progress_made(self, share_id, node_id, n_bytes_written, deflated_size):
+    def progress_made(self, share_id, node_id, n_bytes, deflated_size):
         """Progress made on up- or download."""
         self.aggregator.progress_made(
-            share_id, node_id, n_bytes_written, deflated_size)
+            share_id, node_id, n_bytes, deflated_size)
 
     def queue_done(self):
         """The queue is empty."""
