@@ -2,7 +2,7 @@
 #
 # Author: Facundo Batista <facundo@canonical.com>
 #
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +15,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Module that implements the File System Manager."""
+
 from __future__ import with_statement
 
 import os
@@ -153,8 +167,7 @@ logger = functools.partial(fsm_logger.log, logging.INFO)
 log_warning = functools.partial(fsm_logger.log, logging.WARNING)
 log_debug = functools.partial(fsm_logger.log, logging.DEBUG)
 
-is_forbidden = set("info path node_id share_id is_dir".split()
-                  ).intersection
+is_forbidden = set("info path node_id share_id is_dir".split()).intersection
 
 
 class InconsistencyError(Exception):
@@ -991,7 +1004,7 @@ class FileSystemManager(object):
         mdobj = self.fs[mdid]
         path = self.get_abspath(mdobj['share_id'], mdobj['path'])
         log_debug("move_to_conflict: path=%r mdid=%r", path, mdid)
-        base_to_path = to_path =  path + self.CONFLICT_SUFFIX
+        base_to_path = to_path = path + self.CONFLICT_SUFFIX
         ind = 0
         while path_exists(to_path):
             ind += 1
@@ -1015,7 +1028,8 @@ class FileSystemManager(object):
                 else:
                     raise
 
-        for p, is_dir in self.get_paths_starting_with(path, include_base=False):
+        for p, is_dir in self.get_paths_starting_with(
+        path, include_base=False):
             if is_dir:
                 # remove inotify watch
                 try:
@@ -1051,11 +1065,12 @@ class FileSystemManager(object):
             return mdobj["info"]["partial_path"]
 
         path = self.get_abspath(mdobj['share_id'], mdobj['path'])
-        partial_path = os.path.join(self.partials_dir, mdobj['mdid'] + '.u1partial')
+        partial_path = os.path.join(
+            self.partials_dir, mdobj['mdid'] + '.u1partial')
         dirname, filename = os.path.split(path)
 
         if trim is not None:
-            filename = filename[:-10*trim]
+            filename = filename[:-10 * trim]
             mdobj["info"]["partial_path"] = partial_path + '.' + filename
 
         return partial_path + '.' + filename
@@ -1089,7 +1104,8 @@ class FileSystemManager(object):
         try:
             while True:
                 try:
-                    # don't alert EQ, partials are in other directory, not watched
+                    # don't alert EQ
+                    # partials are in other directory, not watched
                     os_open(partial_path, "w").close()
                 except IOError, e:
                     # linux will give you too long, windows will say invalid
@@ -1436,7 +1452,7 @@ class FileSystemManager(object):
             try:
                 make_dir(full_path)
             except OSError, e:
-                if not e.errno == 17: #already exists
+                if not e.errno == 17:  # already exists
                     raise
 
             if not enable.ro:
