@@ -1,6 +1,6 @@
 # Author: Manuel de la Pena <manuel@canonical.com>
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -13,13 +13,26 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Platfrom independent filesystem notifications code."""
 
 import logging
 import os
 import re
 
-from ubuntuone.platform import path_exists
+from ubuntuone.platform import access, path_exists
 from ubuntuone.syncdaemon.mute_filter import MuteFilter
 from ubuntuone import logger
 # our logging level
@@ -97,7 +110,7 @@ class GeneralINotifyProcessor(object):
         # check first if the platform code knows hat to do with it
         if not self.platform_is_ignored(path):
             # check if we can read
-            if path_exists(path) and not os.access(path, os.R_OK):
+            if path_exists(path) and not access(path):
                 self.log.warning("Ignoring path as we don't have enough "
                                  "permissions to track it: %r", path)
                 return True
@@ -125,6 +138,8 @@ class GeneralINotifyProcessor(object):
 
     def eq_push(self, event_name, **event_data):
         """Sends to EQ the event data, maybe filtering it."""
+        if event_name == 'FS_DIR_DELETE':
+            self.handle_dir_delete(event_data['path'])
         if not self._to_mute.pop(event_name, **event_data):
             self.monitor.eq.push(event_name, **event_data)
 
@@ -149,8 +164,6 @@ class GeneralINotifyProcessor(object):
                 return
 
         if not self.is_ignored(event.pathname):
-            if evt_name == 'FS_DIR_DELETE':
-                self.handle_dir_delete(event.pathname)
             self.eq_push(evt_name, path=event.pathname)
 
     def freeze_begin(self, path):
