@@ -2,7 +2,7 @@
 #
 # Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,6 +15,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Listener for event queue that updates the UI to show syncdaemon status."""
 
 from ubuntuone.status.aggregator import StatusFrontend
@@ -81,10 +94,10 @@ class StatusListener(object):
             share_id, node_id, n_bytes_written, deflated_size)
 
     def handle_AQ_DOWNLOAD_FILE_PROGRESS(self, share_id, node_id,
-                                         n_bytes_written, deflated_size):
+                                         n_bytes_read, deflated_size):
         """Progress has been made on an upload."""
         self.status_frontend.progress_made(
-            share_id, node_id, n_bytes_written, deflated_size)
+            share_id, node_id, n_bytes_read, deflated_size)
     # pylint: enable=W0613
 
     def handle_SYS_QUEUE_ADDED(self, command):
